
---------------------------------------------------------
-- Creacion de secuencias que se usarán para
-- generar las claves primarias de las tablas
---------------------------------------------------------  
CREATE SEQUENCE seq_candidato
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_cliente
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_comercial
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_competencia
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_entrevista_interna
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
    
CREATE SEQUENCE seq_entrevista_externa
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
  
CREATE SEQUENCE seq_pro_captacion
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_pro_seleccion
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_propuesta
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_sede
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_vacante
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;
  
CREATE SEQUENCE seq_visita
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;

 CREATE SEQUENCE seq_log
  MINVALUE 1
  START WITH 1
  INCREMENT BY 1;


--********************************************************
-- Creación de tablas 
--********************************************************
  
  
-- Creación de tabla SEDE  
CREATE TABLE SEDE 
  ( SE_COD_SEDE VARCHAR2(10) NOT NULL,
    SE_TELEFONO NUMBER NOT NULL,
    SE_POBLACION VARCHAR2(50) NOT NULL,
    SE_COD_POSTAL NUMBER NOT NULL,
    SE_DIRECCION VARCHAR2(150) NOT NULL,
    SE_F_INAUGURACION DATE NOT NULL,
    SE_RESPONSABLE VARCHAR2(80),
    CONSTRAINT SEDE_PK PRIMARY KEY(SE_COD_SEDE)
  );
  
-- Creación de tabla PROCESO_CAPTACION
CREATE TABLE PROCESO_CAPTACION
  ( PC_COD_PROC_CAP VARCHAR2(10) NOT NULL,
    PC_TIPO VARCHAR(10) CHECK (PC_TIPO IN ('PRENSA','RADIO','TV','INTERNET','CORREO','OTRO')) NOT NULL,
    PC_F_INICIO DATE NOT NULL,
    PC_F_FIN DATE,
    PC_DETALLES VARCHAR2(1000),
    PC_SEDE_CF VARCHAR2(10) NOT NULL,
    CONSTRAINT PROC_CAP_PK PRIMARY KEY (PC_COD_PROC_CAP),
    CONSTRAINT SEDE_FK FOREIGN KEY (PC_SEDE_CF) REFERENCES SEDE(SE_COD_SEDE) ON DELETE CASCADE
    );
  
	
-- Creación de tabla CLIENTE
CREATE TABLE CLIENTE
  ( CL_COD_CLIENTE VARCHAR2(10) NOT NULL,
    CL_NOMBRE VARCHAR2(50) NOT NULL,
    CL_POBLACION VARCHAR2(50) NOT NULL,
    CL_COD_POSTAL NUMBER NOT NULL,
    CL_DIRECCION VARCHAR2(150) NOT NULL,
    CL_TELEFONO NUMBER NOT NULL,
    CL_CONTACTO VARCHAR(80),
    CL_TFNO_CONTACTO NUMBER,
    CL_EMAIL_CONTACTO VARCHAR(50),
    CL_SEDE_CF VARCHAR2(10),
    CONSTRAINT CLIENTE_PK PRIMARY KEY (CL_COD_CLIENTE),
    CONSTRAINT SEDE_CL_FK FOREIGN KEY (CL_SEDE_CF) REFERENCES SEDE(SE_COD_SEDE) ON DELETE SET NULL
    );
	
	
     
-- Creación de tabla COMERCIAL
CREATE TABLE COMERCIAL
  ( CO_COD_COMERCIAL VARCHAR2(10) NOT NULL,
    CO_NOMBRE VARCHAR2(30) NOT NULL,
    CO_APELLIDOS VARCHAR2(50) NOT NULL,    
    CO_TELEFONO NUMBER NOT NULL,    
    CO_EMAIL VARCHAR(50),
    CO_F_CONTRATACION DATE NOT NULL,
    CO_IMP_PROPUESTAS NUMBER(*,2),
    CO_SEDE_CF VARCHAR2(10) NOT NULL,
    CONSTRAINT COMERCIAL_PK PRIMARY KEY (CO_COD_COMERCIAL),
    CONSTRAINT SEDE_CO_FK FOREIGN KEY (CO_SEDE_CF) REFERENCES SEDE(SE_COD_SEDE) ON DELETE CASCADE
    );  

	
	
	
-- Creación de tabla PROPUESTA
CREATE TABLE PROPUESTA
  ( PR_COD_PROPUESTA VARCHAR2(10) NOT NULL,
	PR_DETALLES VARCHAR2(1000) NOT NULL,
    PR_IMPORTE NUMBER(*,2),
    PR_ES_ACEPTADA CHAR(1)CHECK(PR_ES_ACEPTADA IN ('Y','N')),        
    PR_COMERCIAL_CF VARCHAR(10) NOT NULL,
    PR_CLIENTE_CF VARCHAR(10) NOT NULL,
    PR_F_PROPUESTA DATE,
    PR_F_ACEPTACION DATE,    
    CONSTRAINT PROPUESTA_PK PRIMARY KEY (PR_COD_PROPUESTA),
    CONSTRAINT COMERCIAL_PR_FK FOREIGN KEY (PR_COMERCIAL_CF) REFERENCES COMERCIAL(CO_COD_COMERCIAL) ON DELETE CASCADE,
    CONSTRAINT CLIENTE_PR_FK FOREIGN KEY (PR_CLIENTE_CF) REFERENCES CLIENTE(CL_COD_CLIENTE) ON DELETE CASCADE
    );  
	

	
	
-- Creación de tabla VISITA
CREATE TABLE VISITA
  ( VI_COD_VISITA VARCHAR2(10) NOT NULL,
    VI_FECHA DATE NOT NULL,    
    VI_COMENTARIOS VARCHAR2(1000) NOT NULL,
    VI_COMERCIAL_CF VARCHAR(10) NOT NULL,
	VI_CLIENTE_CF VARCHAR(10) NOT NULL,
    VI_PROPUESTA_CF VARCHAR(10),            
    CONSTRAINT VISITA_PK PRIMARY KEY (VI_COD_VISITA),
    CONSTRAINT COMERCIAL_VI_FK FOREIGN KEY (VI_COMERCIAL_CF) REFERENCES COMERCIAL(CO_COD_COMERCIAL) ON DELETE CASCADE,
    CONSTRAINT PROPUESTA_VI_FK FOREIGN KEY (VI_PROPUESTA_CF) REFERENCES PROPUESTA(PR_COD_PROPUESTA) ON DELETE SET NULL,
    CONSTRAINT CLIENTE_VI_FK FOREIGN KEY (VI_CLIENTE_CF) REFERENCES CLIENTE(CL_COD_CLIENTE) ON DELETE CASCADE
    );  
	
 

	
-- Creación de tabla COMPETENCIA
CREATE TABLE COMPETENCIA
  ( CP_COD_COMPETENCIA VARCHAR2(10) NOT NULL,
	CP_NOMBRE VARCHAR2(30) NOT NULL,
    CP_DESCRIPCION VARCHAR2(1000) NOT NULL,
    CP_F_CREACION DATE DEFAULT SYSDATE,
    CONSTRAINT COMPETENCIA_PK PRIMARY KEY (CP_COD_COMPETENCIA),
	CONSTRAINT NOMBRE_UNIQUE UNIQUE (CP_NOMBRE)
    );  
	
      
-- Creación de tabla CANDIDATO
CREATE TABLE CANDIDATO
  ( CA_COD_CANDIDATO VARCHAR2(10) NOT NULL,
    CA_NOMBRE VARCHAR2(30) NOT NULL,
    CA_APELLIDOS VARCHAR2(50) NOT NULL,    
    CA_F_NACIMIENTO DATE NOT NULL,
    CA_TELEFONO NUMBER NOT NULL,    
    CA_NIVEL_ESTUDIOS VARCHAR2(15) CHECK(CA_NIVEL_ESTUDIOS IN ('ESO','BACHILLERATO','FP','GRADO','MASTER','DOCTORADO')) NOT NULL,
	CA_BUSCA_TRABAJO CHAR(1) CHECK (CA_BUSCA_TRABAJO IN ('Y','N')) NOT NULL,    
	CA_SEDE_CF VARCHAR2(10) NOT NULL,
	CA_EMAIL VARCHAR(50),
    CA_ESPECIALIZACION VARCHAR2(100),
	CA_PROC_CAPTACION_CF VARCHAR2(10),        
    CONSTRAINT CANDIDATO_PK PRIMARY KEY (CA_COD_CANDIDATO),
    CONSTRAINT SEDE_CA_FK FOREIGN KEY (CA_SEDE_CF) REFERENCES SEDE(SE_COD_SEDE) ON DELETE CASCADE,
    CONSTRAINT PROC_CAP_CA_FK FOREIGN KEY (CA_PROC_CAPTACION_CF) REFERENCES PROCESO_CAPTACION(PC_COD_PROC_CAP) ON DELETE SET NULL,
	CONSTRAINT EMAIL_UNIQUE	UNIQUE (CA_EMAIL)
    );  
	
  
-- Creación de tabla PROCESO_SELECCION
CREATE TABLE PROCESO_SELECCION
  ( PS_COD_PROC_SEL VARCHAR2(10) NOT NULL,
    PS_F_INICIO DATE NOT NULL,
	PS_CLIENTE_CF VARCHAR2(10) NOT NULL,
    PS_F_FIN DATE,
    PS_COMENTARIOS VARCHAR2(1000),        
    CONSTRAINT PROCESO_SELECCION_PK PRIMARY KEY (PS_COD_PROC_SEL),
    CONSTRAINT CLIENTE_PS_FK FOREIGN KEY (PS_CLIENTE_CF) REFERENCES CLIENTE(CL_COD_CLIENTE) ON DELETE CASCADE    
    );  
	

  

-- Creación de tabla VACANTE
CREATE TABLE VACANTE
  ( VA_COD_VACANTE VARCHAR2(10) NOT NULL,
	VA_PROC_SEL_CF VARCHAR2(10) NOT NULL,
    VA_NIVEL_ESTUDIOS VARCHAR2(15) CHECK(VA_NIVEL_ESTUDIOS IN ('ESO','BACHILLERATO','FP','GRADO','MASTER','DOCTORADO')) NOT NULL,
    VA_ESPECIALIZACION VARCHAR2(100),    
    VA_NUM_PUESTOS NUMBER CHECK(VA_NUM_PUESTOS > 0) NOT NULL,    
    CONSTRAINT VACANTE_PK PRIMARY KEY (VA_COD_VACANTE),
	CONSTRAINT PROC_SEL_VA_FK FOREIGN KEY (VA_PROC_SEL_CF) REFERENCES PROCESO_SELECCION(PS_COD_PROC_SEL) ON DELETE CASCADE
    );  
	
   

  
-- Creación de tabla ENTREVISTA_INTERNA
CREATE TABLE ENTREVISTA_INTERNA
  ( EI_COD_ENTREVISTA VARCHAR2(10) NOT NULL,
    EI_FECHA DATE NOT NULL,    
	EI_CANDIDATO_CF VARCHAR2(10) NOT NULL,    
	EI_SEDE_CF VARCHAR2(10) NOT NULL,
	EI_SATISFACTORIA CHAR(1) CHECK (EI_SATISFACTORIA IN ('Y','N')),
    EI_COMENTARIOS VARCHAR2(1000),
    CONSTRAINT ENTREVISTA_INTERNA_PK PRIMARY KEY (EI_COD_ENTREVISTA),
    CONSTRAINT CANDIDATO_EI_FK FOREIGN KEY (EI_CANDIDATO_CF) REFERENCES CANDIDATO(CA_COD_CANDIDATO) ON DELETE CASCADE,    
	CONSTRAINT SEDE_EI_FK FOREIGN KEY (EI_SEDE_CF) REFERENCES SEDE(SE_COD_SEDE) ON DELETE CASCADE   
    );  
	
	
	
-- Creación de tabla ENTREVISTA_EXTERNA
CREATE TABLE ENTREVISTA_EXTERNA
  ( EE_COD_ENTREVISTA VARCHAR2(10) NOT NULL,
    EE_FECHA DATE NOT NULL,    
	EE_CANDIDATO_CF VARCHAR2(10) NOT NULL,
	EE_PROC_SEL_CF VARCHAR2(10) NOT NULL,  
    EE_COMENTARIOS VARCHAR2(1000),
    EE_SELECCIONADO CHAR(1) CHECK (EE_SELECCIONADO IN ('Y','N')),
    EE_DESCARTADO CHAR(1) CHECK (EE_DESCARTADO IN ('Y','N')),
    CONSTRAINT ENTREVISTA_EXTERNA_PK PRIMARY KEY (EE_COD_ENTREVISTA),
    CONSTRAINT CANDIDATO_EE_FK FOREIGN KEY (EE_CANDIDATO_CF) REFERENCES CANDIDATO(CA_COD_CANDIDATO) ON DELETE CASCADE,    
    CONSTRAINT PROC_SEL_EE_FK FOREIGN KEY (EE_PROC_SEL_CF) REFERENCES PROCESO_SELECCION(PS_COD_PROC_SEL) ON DELETE CASCADE
    );  
	

  
  
-- Creación de tabla COMPETENCIA_CANDIDATO
CREATE TABLE COMPETENCIA_CANDIDATO
  ( CC_COMPETENCIA_CF VARCHAR2(10) NOT NULL,
    CC_CANDIDATO_CF VARCHAR2(10) NOT NULL,
    CC_EXPERIENCIA VARCHAR2(10) CHECK(CC_EXPERIENCIA IN ('BAJA','ALTA','MEDIA')) NOT NULL,        
    CONSTRAINT COMPETENCIA_CANDIDATO_PK PRIMARY KEY (CC_COMPETENCIA_CF,CC_CANDIDATO_CF),
    CONSTRAINT COMPETENCIA_CC_FK FOREIGN KEY (CC_COMPETENCIA_CF) REFERENCES COMPETENCIA(CP_COD_COMPETENCIA) ON DELETE CASCADE,    
    CONSTRAINT CANDIDATO_CC_FK FOREIGN KEY (CC_CANDIDATO_CF) REFERENCES CANDIDATO(CA_COD_CANDIDATO) ON DELETE CASCADE        
    );  
	
 
-- Creación de tabla COMPETENCIA_VACANTE
CREATE TABLE COMPETENCIA_VACANTE
  ( CV_COMPETENCIA_CF VARCHAR2(10) NOT NULL,
    CV_VACANTE_CF VARCHAR2(10) NOT NULL,
    CV_EXPERIENCIA VARCHAR2(10) CHECK(CV_EXPERIENCIA IN ('BAJA','ALTA','MEDIA')) NOT NULL,        
    CONSTRAINT COMPETENCIA_VACANTE_PK PRIMARY KEY (CV_COMPETENCIA_CF,CV_VACANTE_CF),
    CONSTRAINT COMPETENCIA_CV_FK FOREIGN KEY (CV_COMPETENCIA_CF) REFERENCES COMPETENCIA(CP_COD_COMPETENCIA) ON DELETE CASCADE,    
    CONSTRAINT VACANTE_CV_FK FOREIGN KEY (CV_VACANTE_CF) REFERENCES VACANTE(VA_COD_VACANTE) ON DELETE CASCADE        
    );  
	
 
-- Creación de tabla ENTREVISTA_SELECCION_VACANTE
CREATE TABLE ENTREVISTA_SELECCION_VACANTE
  ( ESV_ENT_EXT_CF VARCHAR2(10) NOT NULL,
    ESV_PROC_SEL_CF VARCHAR2(10) NOT NULL,
    ESV_VACANTE_CF VARCHAR2(10) NOT NULL,        
    CONSTRAINT ENT_SEL_VAC_PK PRIMARY KEY (ESV_ENT_EXT_CF,ESV_PROC_SEL_CF,ESV_VACANTE_CF),    
	CONSTRAINT ENT_EXT_ESV_FK FOREIGN KEY (ESV_ENT_EXT_CF) REFERENCES ENTREVISTA_EXTERNA(EE_COD_ENTREVISTA) ON DELETE CASCADE,    
	CONSTRAINT PROC_SEL_ESV_FK FOREIGN KEY (ESV_PROC_SEL_CF) REFERENCES PROCESO_SELECCION(PS_COD_PROC_SEL) ON DELETE CASCADE,  
    CONSTRAINT VACANTE_ESV_FK FOREIGN KEY (ESV_VACANTE_CF) REFERENCES VACANTE(VA_COD_VACANTE) ON DELETE CASCADE        
    );  
	
    

--********************************************************
-- Creación de tablas del Data Warehouse
--********************************************************
	
-- Creación de tabla para computar las entrevistas internas realizadas / año
CREATE TABLE DW_ENT_INT_ANYO
  ( EIA_ANYO NUMBER(4) NOT NULL,
    EIA_NUM_ENT_INT NUMBER NOT NULL,    
    CONSTRAINT ENT_INT_ANYO_PK PRIMARY KEY (EIA_ANYO)    
    );  
  
-- Creación de tabla para computar el porcentaje de procesos de selección en los que 
-- se contrató a un candidato, sobre el total de procesos realizados en un año concreto
CREATE TABLE DW_RATIO_PRO_SEL_EXITO
  ( RPS_ANYO NUMBER(4) NOT NULL,
	RPS_NUM_PRO_EXITO NUMBER NOT NULL,
    RPS_NUM_PRO_SEL NUMBER NOT NULL,    
    RPS_RATIO_ANUAL NUMBER(*,3) NOT NULL,
    CONSTRAINT RATIO_PRO_SEL_PK PRIMARY KEY (RPS_ANYO)    
    );  
	

-- Creación de tabla para computar el porcentaje de candidatos no seleccionados en ningún proceso, 
-- sobre el total de candidatos en el sistema a la fecha de la consulta
CREATE TABLE DW_RATIO_CAN_INACTIVOS
  ( RCI_FECHA TIMESTAMP NOT NULL,
    RCI_CAN_INACTIVOS NUMBER NOT NULL,
    RCI_CAN_TOTALES NUMBER NOT NULL,
    RCI_RATIO NUMBER(*,3) NOT NULL,
    CONSTRAINT RATIO_CAN_INACTIVOS_PK PRIMARY KEY (RCI_FECHA)    
    );  
	
-- Creación de tabla para computar el importe total de las propuestas aceptadas por clientes en un año dado
CREATE TABLE DW_IMP_PROPUESTAS_ACEPTADAS
  ( IPA_ANYO NUMBER(4) NOT NULL,
    IPA_IMPORTE_TOTAL NUMBER(*,2) NOT NULL,    
    CONSTRAINT IMP_PROPUESTAS_ACEPTADAS_PK PRIMARY KEY (IPA_ANYO)    
    );  	
  
    
-- Creación de tabla para determinar el comercial con el mayor porcentaje 
-- de éxito (propuestas aceptadas sobre el total) al momento de la consulta
CREATE TABLE DW_LIDER_COMERCIAL
  ( LC_FECHA TIMESTAMP NOT NULL,
    LC_COMERCIAL_CF VARCHAR2(10) NOT NULL,
    LC_PROP_EXITO NUMBER NOT NULL,
    LC_PROP_TOTALES NUMBER NOT NULL,
    LC_RATIO NUMBER(*,3) NOT NULL,
    CONSTRAINT LIDER_COMERCIAL_PK PRIMARY KEY (LC_FECHA),    
    CONSTRAINT COMERCIAL_LC_FK FOREIGN KEY (LC_COMERCIAL_CF) REFERENCES COMERCIAL(CO_COD_COMERCIAL) ON DELETE CASCADE        
    );  
	
	   
  
-- Creación de tabla para determinar el proceso de captación más exitoso 
-- (con el mayor número de candidatos seleccionados) hasta el momento de la consulta
CREATE TABLE DW_CAPTACION_HIST_EXITO
  ( CHE_FECHA TIMESTAMP NOT NULL,
    CHE_PROC_CAP_CF VARCHAR2(10) NOT NULL,
    CHE_NUM_CAN NUMBER NOT NULL,    
    CONSTRAINT CAPTACION_HIST_EXITO_PK PRIMARY KEY (CHE_FECHA),    
    CONSTRAINT PROC_CAP_CHE_FK FOREIGN KEY (CHE_PROC_CAP_CF) REFERENCES PROCESO_CAPTACION(PC_COD_PROC_CAP) ON DELETE CASCADE
    );  
 
-- Creación de tabla para determinar el Top 10 de niveles de estudios 
-- más solicitados en los procesos de selección en un año dado
CREATE TABLE DW_TOP_TEN_ESTUDIOS
  ( TTE_ANYO NUMBER(4) NOT NULL,
    TTE_NIV_EST_1 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_1 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_2 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_2 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_3 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_3 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_4 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_4 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_5 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_5 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_6 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_6 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_7 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_7 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_8 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_8 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_9 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_9 VARCHAR2(100) NOT NULL,
    TTE_NIV_EST_10 VARCHAR2(15) NOT NULL,
    TTE_ESPEC_10 VARCHAR2(100) NOT NULL,        
    CONSTRAINT TOP_TEN_ESTUDIOS_PK PRIMARY KEY (TTE_ANYO)    
    );  
  
  
-- Creación de tabla para determinar el Top 5 de competencias más demandadas 
-- (las más comunes entre las vacantes ofertadas) en un año dado
CREATE TABLE DW_TOP_FIVE_COMPETENCIAS
  ( TFC_ANYO NUMBER(4) NOT NULL,
    TFC_COMP_1 VARCHAR2(30) NOT NULL,
    TFC_COMP_2 VARCHAR2(30) NOT NULL,
    TFC_COMP_3 VARCHAR2(30) NOT NULL,
    TFC_COMP_4 VARCHAR2(30) NOT NULL,
    TFC_COMP_5 VARCHAR2(30) NOT NULL,        
    CONSTRAINT TOP_FIVE_COMPETENCIAS_PK PRIMARY KEY (TFC_ANYO)    
    );  
	
	
-- Creación de tabla para determinar Cliente que más candidatos 
-- de los propuestos ha contratado al momento de hacer la consulta
CREATE TABLE DW_CLIENTE_TOP_CONTRATACIONES
  ( CTC_FECHA TIMESTAMP NOT NULL,
    CTC_COD_CLIENTE_CF VARCHAR2(10) NOT NULL,
    CTC_NUM_CONTRA NUMBER NOT NULL,
    CONSTRAINT CLIENTE_TOP_CONTRATACIONES_PK PRIMARY KEY (CTC_FECHA),
    CONSTRAINT CLIENTE_CTC_FK FOREIGN KEY (CTC_COD_CLIENTE_CF) REFERENCES CLIENTE(CL_COD_CLIENTE) ON DELETE CASCADE
    );  
	
	
-- Creación de tabla para determinar el Cliente que más propuestas ha rechazado en un año dado
CREATE TABLE DW_CLIENTE_PROP_RECHAZADAS
  ( CPR_ANYO NUMBER(4) NOT NULL,
    CPR_CLIENTE_CF VARCHAR2(10) NOT NULL,
    CPR_NUM_RECHAZOS NUMBER NOT NULL,
    CONSTRAINT CLIENTE_PROP_RECHAZADAS_PK PRIMARY KEY (CPR_ANYO),
    CONSTRAINT CLIENTE_CPR_FK FOREIGN KEY (CPR_CLIENTE_CF) REFERENCES CLIENTE(CL_COD_CLIENTE) ON DELETE CASCADE
    );  
	
	
-- Creación de tabla para determinar el Comercial que más visitas ha realizado durante el año actual
CREATE TABLE DW_COMERCIAL_TOP_VISITAS
  ( CTV_ANYO NUMBER(4) NOT NULL,
    CTV_COMERCIAL_CF VARCHAR2(10) NOT NULL,
    CTV_NUM_VISITAS NUMBER NOT NULL,
    CONSTRAINT COMERCIAL_TOP_VISITAS_PK PRIMARY KEY (CTV_ANYO),
    CONSTRAINT COMERCIAL_CTV_FK FOREIGN KEY (CTV_COMERCIAL_CF) REFERENCES COMERCIAL(CO_COD_COMERCIAL) ON DELETE CASCADE
    );  
	
	
-- Creación de tabla para determinar el Proceso de captación 
-- que más candidatos contratados aportó durante el año actual
CREATE TABLE DW_CAPTACION_TOP_ANUAL
  ( CTA_ANYO NUMBER(4) NOT NULL,
    CTA_PROCESO_CAPTACION_CF VARCHAR2(10) NOT NULL,
    CTA_NUM_CONTRA NUMBER NOT NULL,
    CONSTRAINT CAPTACION_TOP_ANUAL_PK PRIMARY KEY (CTA_ANYO),
    CONSTRAINT PROC_CAP_CTA_FK FOREIGN KEY (CTA_PROCESO_CAPTACION_CF) REFERENCES PROCESO_CAPTACION(PC_COD_PROC_CAP) ON DELETE CASCADE
    );  
	
-- Creación de tabla para determinar la sede que 
-- ha realizado menos entrevistas internas durante el año actual
CREATE TABLE DW_SEDE_MENOS_ENTREVISTAS
  ( SME_ANYO NUMBER(4) NOT NULL,
    SME_SEDE_CF VARCHAR2(10) NOT NULL,
    SME_NUM_ENTR NUMBER NOT NULL,
    CONSTRAINT SEDE_MENOS_ENTR_PK PRIMARY KEY (SME_ANYO),
    CONSTRAINT SEDE_SME_FK FOREIGN KEY (SME_SEDE_CF) REFERENCES SEDE(SE_COD_SEDE) ON DELETE CASCADE
    );  
	
	

--********************************************************
-- Creación de tabla de logs
--********************************************************
		

-- Creación de tabla LOG
CREATE TABLE LOG
  ( LOG_ID VARCHAR2(20) NOT NULL,
    LOG_PROCEDIMIENTO VARCHAR2(30) NOT NULL,
	LOG_PAR_ENTRADA VARCHAR2(2000) NOT NULL,	
	LOG_COD_SALIDA CHAR(1) CHECK (LOG_COD_SALIDA IN ('0','1')) NOT NULL,
	LOG_RSP VARCHAR2(150) NOT NULL,
	LOG_FECHA TIMESTAMP NOT NULL,	 
    CONSTRAINT LOG_PK PRIMARY KEY (LOG_ID)    
    );


--********************************************************
-- Creación de índices adicionales a los de clave primaria
--********************************************************
	
CREATE INDEX IND_CA_SEDE ON CANDIDATO(CA_SEDE_CF);
CREATE INDEX IND_CA_APE_NOM ON CANDIDATO(CA_APELLIDOS,CA_NOMBRE);
CREATE INDEX IND_CL_NOMBRE ON CLIENTE(CL_NOMBRE);
CREATE INDEX IND_CO_APE ON COMERCIAL(CO_APELLIDOS,CO_NOMBRE);
CREATE INDEX IND_CO_IMPORTE ON COMERCIAL(CO_IMP_PROPUESTAS);
CREATE INDEX IND_CP_F_CREACION ON COMPETENCIA(CP_F_CREACION);
CREATE INDEX IND_EE_FECHA ON ENTREVISTA_EXTERNA(EE_FECHA);
CREATE INDEX IND_EI_FECHA ON ENTREVISTA_INTERNA(EI_FECHA);
CREATE INDEX IND_PC_FECHA ON PROCESO_CAPTACION(PC_F_INICIO,PC_F_FIN);
CREATE INDEX IND_PS_FECHA ON PROCESO_SELECCION(PS_F_INICIO,PS_F_FIN);
CREATE INDEX IND_PR_COMERCIAL ON PROPUESTA(PR_COMERCIAL_CF,PR_ES_ACEPTADA);
CREATE INDEX IND_PR_CLIENTE ON PROPUESTA(PR_CLIENTE_CF);
CREATE INDEX IND_VA_ESTUDIOS ON VACANTE(VA_NIVEL_ESTUDIOS,VA_ESPECIALIZACION);
CREATE INDEX IND_VI_FECHA ON VISITA(VI_FECHA);
CREATE INDEX IND_LOG_PROC ON LOG(LOG_PROCEDIMIENTO,LOG_COD_SALIDA);

