/*
************************************************
****	PROCEDIMIENTOS & DISPARADORES	 	 ***
************************************************/
--------------------------------------------------------
--  DDL for Procedure PA_INSERTA_LOG
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_INSERTA_LOG" (
	PROCEDIMIENTO RC.LOG.LOG_PROCEDIMIENTO%TYPE,
	PAR_ENTRADA RC.LOG.LOG_PAR_ENTRADA%TYPE,
	COD_SALIDA RC.LOG.LOG_COD_SALIDA%TYPE,	
	RSP RC.LOG.LOG_RSP%TYPE) 
IS 
  PRAGMA AUTONOMOUS_TRANSACTION;
BEGIN
  INSERT INTO LOG(
    LOG_PROCEDIMIENTO,
    LOG_PAR_ENTRADA,    
    LOG_COD_SALIDA,
    LOG_RSP,
    LOG_FECHA)
  VALUES(
    PROCEDIMIENTO,
    PAR_ENTRADA,
    COD_SALIDA,
    RSP,
    SYSTIMESTAMP);
  COMMIT;
END PA_INSERTA_LOG;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_CANDIDATO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_CANDIDATO" (	
  NOMBRE          IN 	RC.CANDIDATO.CA_NOMBRE%TYPE,
  APELLIDOS       IN 	RC.CANDIDATO.CA_APELLIDOS%TYPE,
  EMAIL 	        IN 	RC.CANDIDATO.CA_EMAIL%TYPE,
  F_NAC   	      IN 	RC.CANDIDATO.CA_F_NACIMIENTO%TYPE,
  TFNO            IN 	RC.CANDIDATO.CA_TELEFONO%TYPE,
  N_ESTUDIOS      IN  RC.CANDIDATO.CA_NIVEL_ESTUDIOS%TYPE,
  BUSCA_TRABAJO   IN  RC.CANDIDATO.CA_BUSCA_TRABAJO%TYPE,
  SEDE            IN  RC.CANDIDATO.CA_SEDE_CF%TYPE,  
  ESPECIALIZACION IN 	RC.CANDIDATO.CA_ESPECIALIZACION%TYPE,
  PRO_CAP         IN  RC.CANDIDATO.CA_PROC_CAPTACION_CF%TYPE,
  COMPETENCIAS    IN  VARCHAR2,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.CANDIDATO.CA_COD_CANDIDATO%TYPE;
  EXCEPCION       EXCEPTION;
  NUM_COMP        NUMBER;
  AUX_COMP        VARCHAR2(10);
  AUX_EXP         VARCHAR2(15);
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_CANDIDATO';
  PAR_ENTRADA := 'NOMBRE: ' || NOMBRE || ', APELLIDOS: ' || APELLIDOS || ', FECHA DE NACIMIENTO: ' || F_NAC ||', TELEFONO: ' || TFNO || ', E-MAIL: ' || EMAIL || 
                 ', NIVEL DE ESTUDIOS: ' || N_ESTUDIOS || ', ESPECIALIZACION: ' || ESPECIALIZACION || ', BUSCANDO TRABAJO: ' || BUSCA_TRABAJO || ', CODIGO DE SEDE: ' || SEDE ||
                 ', PROCESO DE CAPTACION: ' || PRO_CAP;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF NOMBRE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NOMBRE DEL CANDIDATO';    
  ELSIF APELLIDOS IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LOS APELLIDOS DEL CANDIDATO';
  ELSIF F_NAC IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA DE NACIMIENTO';  
  ELSIF TFNO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL TELEFONO';
  ELSIF N_ESTUDIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NIVEL DE ESTUDIOS';
  ELSIF BUSCA_TRABAJO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR SI EL CANDIDATO BUSCA TRABAJO';  
  ELSIF SEDE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA SEDE';  
  ELSIF UPPER(BUSCA_TRABAJO) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI EL CANDIDATO BUSCA TRABAJO CON Y/N';  
  ELSIF UPPER(N_ESTUDIOS) NOT IN ('ESO','BACHILLERATO','FP','GRADO','MASTER','DOCTORADO') THEN
    RESPUESTA := 'ERROR. EL NIVEL DE ESTUDIOS DEBE SER ALGUNO ENTRE: ESO,BACHILLERATO,FP,GRADO,MASTER,DOCTORADO';
  ELSE  
    -- Se controla que la sede exista
    SELECT COUNT(*) INTO CF_EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(SEDE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(SEDE);
    END IF;      
  END IF;
  
  -- si se indica un proceso de captacion, se comprueba que existe
  IF PRO_CAP IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM PROCESO_CAPTACION WHERE PC_COD_PROC_CAP=UPPER(PRO_CAP);    
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE CAPTACION CON CODIGO ' || UPPER(PRO_CAP);
    END IF;
  END IF;
   
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
    SAVEPOINT inserta_candidato;
	INSERT INTO CANDIDATO(				        
    CA_NOMBRE,
    CA_APELLIDOS,    
    CA_F_NACIMIENTO,
    CA_TELEFONO,
    CA_NIVEL_ESTUDIOS,
    CA_BUSCA_TRABAJO,    
    CA_SEDE_CF,
    CA_EMAIL,
    CA_ESPECIALIZACION,
    CA_PROC_CAPTACION_CF)
	VALUES(
		NOMBRE,
		APELLIDOS,
		F_NAC,
    TFNO,
		UPPER(N_ESTUDIOS),
    UPPER(BUSCA_TRABAJO),    
    UPPER(SEDE),    
    EMAIL,
    ESPECIALIZACION,
    UPPER(PRO_CAP))
  RETURNING CA_COD_CANDIDATO INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR EL CANDIDATO';
    RAISE EXCEPCION;
  ELSE   
    -- se aÃ±aden las competencias. Si no son vÃ¡lidas se hace rollback
    IF COMPETENCIAS IS NOT NULL THEN
      NUM_COMP := REGEXP_COUNT(COMPETENCIAS, '<COMPETENCIA>',1,'i');    
      FOR i IN 1..NUM_COMP LOOP          
        AUX_COMP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'), 
              REGEXP_INSTR(COMPETENCIAS,'</COMPETENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'));                  
        AUX_EXP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'), 
             REGEXP_INSTR(COMPETENCIAS,'</EXPERIENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'));                       
        -- Se comprueba que la competencia existe      
        SELECT COUNT(*) INTO CF_EXISTE FROM COMPETENCIA WHERE CP_COD_COMPETENCIA=UPPER(AUX_COMP);    
          IF CF_EXISTE = 0 THEN          
            RESPUESTA := 'ERROR. NO EXISTE NINGUNA COMPETENCIA CON CODIGO ' || UPPER(AUX_COMP);
            ROLLBACK TO inserta_candidato;
            RAISE EXCEPCION;          
          ELSE             
            -- se asocia la competencia con el candidato
            IF UPPER(AUX_EXP) = 'ALTA' OR UPPER(AUX_EXP) = 'MEDIA' OR UPPER(AUX_EXP) = 'BAJA' THEN
              INSERT INTO COMPETENCIA_CANDIDATO (CC_COMPETENCIA_CF,CC_CANDIDATO_CF,CC_EXPERIENCIA)
                        VALUES(UPPER(AUX_COMP),COD_ASIGNADO,UPPER(AUX_EXP));
            ELSE 
              RESPUESTA := 'ERROR. LA EXPERIENCIA NO PUEDE SER ' || UPPER(AUX_EXP) || '. HA DE SER ALTA, MEDIA O BAJA.';
              ROLLBACK TO inserta_candidato;
              RAISE EXCEPCION; 
            END IF;
            -- Se comprueba que se ha introducido la nueva fila  
            IF SQL%ROWCOUNT != 1 THEN
              RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA COMPETENCIA ' || AUX_COMP || ' AL CANDIDATO ' || COD_ASIGNADO;
              ROLLBACK TO inserta_candidato;
              RAISE EXCEPCION;            
            END IF; 
          END IF;
      END LOOP;    
    END IF;
    
    RESPUESTA := 'OK. CANDIDATO [' || COD_ASIGNADO || '] AÃ‘ADIDO CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_CANDIDATO;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_CLIENTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_CLIENTE" (
  CONTACTO      IN 	RC.CLIENTE.CL_CONTACTO%TYPE,  
  DIRECCION     IN 	RC.CLIENTE.CL_DIRECCION%TYPE,
  POBLACION     IN 	RC.CLIENTE.CL_POBLACION%TYPE,  
  EMAIL_CONT    IN 	RC.CLIENTE.CL_EMAIL_CONTACTO%TYPE,
  C_POSTAL      IN 	RC.CLIENTE.CL_COD_POSTAL%TYPE,
	NOMBRE	      IN 	RC.CLIENTE.CL_NOMBRE%TYPE,  
  TFNO		      IN 	RC.CLIENTE.CL_TELEFONO%TYPE,  
  TFNO_CONT     IN 	RC.CLIENTE.CL_TFNO_CONTACTO%TYPE,  
  COD_SEDE      IN 	RC.CLIENTE.CL_SEDE_CF%TYPE,  
	COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.CLIENTE.CL_COD_CLIENTE%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_CLIENTE';
  PAR_ENTRADA := 'NOMBRE: ' || NOMBRE || ', POBLACION: ' || POBLACION || ', CODIGO POSTAL: ' || C_POSTAL || ', DIRECCION: ' || DIRECCION || 
                 ', TELEFONO: ' || TFNO || ', CONTACTO: ' || CONTACTO || ', TELEFONO-PERSONA CONTACTO: ' || TFNO_CONT || 
                 ', EMAIL-PERSONA CONTACTO: ' || EMAIL_CONT || ', CODIGO DE SEDE: ' || COD_SEDE;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF NOMBRE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NOMBRE DEL CLIENTE';    
  ELSIF POBLACION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA POBLACION';
  ELSIF C_POSTAL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO POSTAL';
  ELSIF DIRECCION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA DIRECCION';
  ELSIF TFNO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL TELEFONO';
  ELSIF COD_SEDE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA SEDE';
  ELSE  
    -- Se controla que la sede exista
    SELECT COUNT(*) INTO CF_EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(COD_SEDE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(COD_SEDE);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
      
	INSERT INTO CLIENTE(				    
    CL_NOMBRE,
    CL_POBLACION,
    CL_COD_POSTAL,
    CL_DIRECCION,
    CL_TELEFONO,
    CL_CONTACTO,
    CL_TFNO_CONTACTO,
    CL_EMAIL_CONTACTO,
    CL_SEDE_CF)
	VALUES(
		NOMBRE,
		POBLACION,
		C_POSTAL,
		DIRECCION,
    TFNO,
    CONTACTO,
    TFNO_CONT,
    EMAIL_CONT,    
		UPPER(COD_SEDE))
  RETURNING CL_COD_CLIENTE INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR EL CLIENTE';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. CLIENTE [' || COD_ASIGNADO || '] AÃ‘ADIDO CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_CLIENTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_COMERCIAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_COMERCIAL" (	
	NOMBRE	      IN 	RC.COMERCIAL.CO_NOMBRE%TYPE,
  APELLIDOS     IN 	RC.COMERCIAL.CO_APELLIDOS%TYPE,
  EMAIL	        IN 	RC.COMERCIAL.CO_EMAIL%TYPE,
  TFNO          IN 	RC.COMERCIAL.CO_TELEFONO%TYPE,  
  F_CONTR	      IN 	RC.COMERCIAL.CO_F_CONTRATACION%TYPE,    
  COD_SEDE      IN 	RC.COMERCIAL.CO_SEDE_CF%TYPE,  
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.COMERCIAL.CO_COD_COMERCIAL%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_COMERCIAL';
  PAR_ENTRADA := 'NOMBRE: ' || NOMBRE || ', APELLIDOS: ' || APELLIDOS || ', TELEFONO: ' || TFNO || ', E-MAIL: ' || EMAIL || 
                 ', FECHA DE CONTRATACION: ' || F_CONTR || ', CODIGO DE SEDE: ' || COD_SEDE;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF NOMBRE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NOMBRE DEL COMERCIAL';    
  ELSIF APELLIDOS IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LOS APELLIDOS DEL COMERCIAL';
  ELSIF TFNO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL TELEFONO';
  ELSIF F_CONTR IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA DE CONTRATACION';
  ELSIF COD_SEDE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA SEDE';  
  ELSE  
    -- Se controla que la sede exista
    SELECT COUNT(*) INTO CF_EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(COD_SEDE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(COD_SEDE);
    END IF;      
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
     
	INSERT INTO COMERCIAL(				        
    CO_NOMBRE,
    CO_APELLIDOS,    
    CO_TELEFONO,    
    CO_EMAIL,
    CO_F_CONTRATACION,    
    CO_SEDE_CF)
	VALUES(
		NOMBRE,
		APELLIDOS,
		TFNO,
		EMAIL,
    F_CONTR,        
		UPPER(COD_SEDE))
  RETURNING CO_COD_COMERCIAL INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR EL COMERCIAL';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. COMERCIAL [' || COD_ASIGNADO || '] AÃ‘ADIDO CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_COMERCIAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_COMPETENCIA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_COMPETENCIA" (	
	NOMBRE        IN RC.COMPETENCIA.CP_NOMBRE%TYPE,
  DESCRIPCION   IN 	RC.COMPETENCIA.CP_DESCRIPCION%TYPE,  
  F_CREACION    IN 	RC.COMPETENCIA.CP_F_CREACION%TYPE,
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;  
  COD_ASIGNADO    RC.COMPETENCIA.CP_COD_COMPETENCIA%TYPE;
  EXCEPCION       EXCEPTION;
  FECHA           DATE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_COMPETENCIA';
  PAR_ENTRADA := 'DESCRIPCION: ' || DESCRIPCION || ', FECHA DE CREACION: ' || F_CREACION;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF NOMBRE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INTRODUCIR EL NOMBRE';    
    RAISE EXCEPCION;
  ELSIF DESCRIPCION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INTRODUCIR UNA DESCRIPCION';    
    RAISE EXCEPCION;
  END IF;  
     
  -- Si no se da una fecha, se usa la actual
  IF F_CREACION IS NULL THEN
    FECHA := SYSDATE;
  ELSE
    FECHA := F_CREACION;
  END IF;
  
	INSERT INTO COMPETENCIA(
    CP_NOMBRE,
    CP_DESCRIPCION,    
    CP_F_CREACION)
	VALUES(
    NOMBRE,
		DESCRIPCION,
		FECHA)
  RETURNING CP_COD_COMPETENCIA INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA COMPETENCIA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. COMPETENCIA [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_COMPETENCIA;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_ENT_EXT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_ENT_EXT" (
	FECHA         IN 	RC.ENTREVISTA_EXTERNA.EE_FECHA%TYPE,
  CANDIDATO     IN 	RC.ENTREVISTA_EXTERNA.EE_CANDIDATO_CF%TYPE,
  PROC_SEL      IN 	RC.ENTREVISTA_EXTERNA.EE_PROC_SEL_CF%TYPE,
  VACANTES      IN  VARCHAR2,
  COMENTARIOS   IN 	RC.ENTREVISTA_EXTERNA.EE_COMENTARIOS%TYPE,  
  SELECCIONADO  IN 	RC.ENTREVISTA_EXTERNA.EE_SELECCIONADO%TYPE,
  DESCARTADO    IN 	RC.ENTREVISTA_EXTERNA.EE_DESCARTADO%TYPE,
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.ENTREVISTA_EXTERNA.EE_COD_ENTREVISTA%TYPE;
  COD_CLIENTE     RC.CLIENTE.CL_COD_CLIENTE%TYPE;
  EXCEPCION       EXCEPTION;
  NUM_VAC         NUMBER;
  AUX_VAC         VARCHAR2(10);
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_ENT_EXT';
  PAR_ENTRADA := 'FECHA: ' || FECHA || ', CANDIDATO: ' || CANDIDATO || ', PROCESO DE SELECCION: ' || PROC_SEL || 
                 ', VACANTE(S): ' || VACANTES || ', COMENTARIOS: ' || COMENTARIOS || ', SELECCIONADO: ' || SELECCIONADO || 
                 ', DESCARTDO: ' || DESCARTADO;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
    
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF FECHA IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA';    
  ELSIF CANDIDATO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CANDIDATO';
  ELSIF PROC_SEL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL PROCESO DE SELECCION';
  ELSIF VACANTES IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR AL MENOS UNA VACANTE';  
  ELSIF SELECCIONADO IS NOT NULL AND UPPER(SELECCIONADO) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI EL CANDIDATO HA SIDO SELECCIONADO CON Y/N';
  ELSIF DESCARTADO IS NOT NULL AND UPPER(DESCARTADO) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI EL CANDIDATO HA SIDO DESCARTADO CON Y/N';
  ELSIF UPPER(SELECCIONADO) = 'Y' AND UPPER(DESCARTADO) ='Y' THEN
    RESPUESTA := 'ERROR. NO ES POSIBLE SELECCIONAR A UN CANDIDATO Y DESCARTARLO A LA VEZ';
  ELSIF UPPER(DESCARTADO) = 'Y' AND COMENTARIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES NECESARIO AÃ‘ADIR COMENTARIOS CUANDO SE DESCARTA PERMANENTEMENTE A UN CANDIDATO';
  ELSE      
    -- Se controla que candidato y proceso de seleccion existen, y que el candidato no ha sido previamente descartado por la empresa
    SELECT COUNT(*) INTO CF_EXISTE FROM CANDIDATO WHERE CA_COD_CANDIDATO=UPPER(CANDIDATO);    
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN CANDIDATO CON CODIGO ' || UPPER(CANDIDATO);            
    ELSE      
      SELECT COUNT(*) INTO CF_EXISTE FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL=UPPER(PROC_SEL);
      IF CF_EXISTE = 0 THEN
        RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE SELECCION CON CODIGO ' || UPPER(PROC_SEL);
      END IF;
    END IF;
	
    IF RESPUESTA IS NULL THEN 
      -- Se obtiene en primer lugar el codigo del cliente asociado al proceso de selecciÃ³n 
      SELECT PS_CLIENTE_CF INTO COD_CLIENTE FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL = UPPER(PROC_SEL);
      -- Se comprueba que no hay ninguna entrevista anterior del candidato con el cliente en la que Ã©ste lo descartara definitivamente
      SELECT COUNT(*) 
        INTO CF_EXISTE 
        FROM ENTREVISTA_EXTERNA E
        JOIN PROCESO_SELECCION P
        ON E.EE_PROC_SEL_CF = P.PS_COD_PROC_SEL
        WHERE P.PS_CLIENTE_CF = UPPER(COD_CLIENTE)
        AND E.EE_CANDIDATO_CF = UPPER(CANDIDATO)
        AND E.EE_DESCARTADO = 'Y';
      IF CF_EXISTE != 0 THEN
          RESPUESTA := 'ERROR. EL CANDIDATO ' || UPPER(CANDIDATO) || 'YA FUE DESCARTADO EN EL PASADO POR EL CLIENTE ' || UPPER(COD_CLIENTE);
      END IF;    
    END IF;   
  END IF;
    
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
    SAVEPOINT inserta_ent_ext;
	INSERT INTO ENTREVISTA_EXTERNA(    
    EE_FECHA,    
    EE_CANDIDATO_CF,
    EE_PROC_SEL_CF,  
    EE_COMENTARIOS,
    EE_SELECCIONADO,
    EE_DESCARTADO)
	VALUES(
		FECHA,
		UPPER(CANDIDATO),
    UPPER(PROC_SEL),
		COMENTARIOS,		
    UPPER(SELECCIONADO),    
    UPPER(DESCARTADO))
  RETURNING EE_COD_ENTREVISTA INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA ENTREVISTA EXTERNA';
    RAISE EXCEPCION;
  ELSE    
  
  -- se aÃ±aden las vacantes. Si no son vÃ¡lidas se hace rollback
  NUM_VAC := REGEXP_COUNT(VACANTES, '<VACANTE>',1,'i');    
      FOR i IN 1..NUM_VAC LOOP          
        AUX_VAC := SUBSTR(VACANTES, REGEXP_INSTR(VACANTES,'<VACANTE>',1,i,1,'i'), 
              REGEXP_INSTR(VACANTES,'</VACANTE>',1,i,0,'i') - REGEXP_INSTR(VACANTES,'<VACANTE>',1,i,1,'i'));                  
        
        -- Se comprueba que la vacante existe      
        SELECT COUNT(*) INTO CF_EXISTE FROM VACANTE WHERE VA_COD_VACANTE=UPPER(AUX_VAC);    
          IF CF_EXISTE = 0 THEN          
            RESPUESTA := 'ERROR. NO EXISTE NINGUNA VACANTE CON CODIGO ' || UPPER(AUX_VAC);
            ROLLBACK to inserta_ent_ext;
            RAISE EXCEPCION;
          ELSE
            -- se asocia la competencia con el candidato
            INSERT INTO ENTREVISTA_SELECCION_VACANTE (ESV_ENT_EXT_CF,ESV_PROC_SEL_CF,ESV_VACANTE_CF)
                        VALUES(COD_ASIGNADO,UPPER(PROC_SEL),UPPER(AUX_VAC));
            -- Se comprueba que se ha introducido la nueva fila  
            IF SQL%ROWCOUNT != 1 THEN
              RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA VACANTE ' || AUX_VAC || ' A LA ENTREVISTA ' || COD_ASIGNADO;
              ROLLBACK to inserta_ent_ext;
              RAISE EXCEPCION;            
            END IF; 
          END IF;
      END LOOP;    
    END IF;
  
    RESPUESTA := 'OK. ENTREVISTA EXTERNA [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;   
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_ENT_EXT;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_ENT_INT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_ENT_INT" (
	FECHA         IN 	RC.ENTREVISTA_INTERNA.EI_FECHA%TYPE,  
  CANDIDATO     IN 	RC.ENTREVISTA_INTERNA.EI_CANDIDATO_CF%TYPE,
  SEDE          IN  RC.ENTREVISTA_INTERNA.EI_SEDE_CF%TYPE,
  SATISFACTORIA IN 	RC.ENTREVISTA_INTERNA.EI_SATISFACTORIA%TYPE,  
  COMENTARIOS   IN 	RC.ENTREVISTA_INTERNA.EI_COMENTARIOS%TYPE,    
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.ENTREVISTA_INTERNA.EI_COD_ENTREVISTA%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_ENT_INT';
  PAR_ENTRADA := 'FECHA: ' || FECHA || ', CANDIDATO: ' || CANDIDATO || ', SEDE: ' || SEDE || 
                 ', SATISFACTORIA: ' || SATISFACTORIA || ', COMENTARIOS: ' || COMENTARIOS; 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
    
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF FECHA IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA';    
  ELSIF CANDIDATO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CANDIDATO';
  ELSIF SEDE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA SEDE'; 
  ELSIF SATISFACTORIA IS NOT NULL AND UPPER(SATISFACTORIA) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI LA ENTREVISTA HA SIDO SATISFACTORIA CON Y/N';
  ELSIF SATISFACTORIA = 'N' AND COMENTARIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES NECESARIO INTRODUCIR COMENTARIOS CUANDO EL CANDIDATO ES DESCARTADO';
  ELSE      
    -- Se controla que candidato y sede existen
    SELECT COUNT(*) INTO CF_EXISTE FROM CANDIDATO WHERE CA_COD_CANDIDATO=UPPER(CANDIDATO);    
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN CANDIDATO CON CODIGO ' || UPPER(CANDIDATO);      
    ELSE      
      SELECT COUNT(*) INTO CF_EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(SEDE);
      IF CF_EXISTE = 0 THEN
        RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(SEDE);
      END IF;
    END IF;  
  END IF;
    
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
     
	INSERT INTO ENTREVISTA_INTERNA(    
    EI_FECHA,    
    EI_CANDIDATO_CF,    
    EI_SEDE_CF,
    EI_SATISFACTORIA,
    EI_COMENTARIOS)
	VALUES(
		FECHA,
		CANDIDATO,
    UPPER(SEDE),
		UPPER(SATISFACTORIA),		
    COMENTARIOS)
  RETURNING EI_COD_ENTREVISTA INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA ENTREVISTA INTERNA';
    RAISE EXCEPCION;
  ELSE        
    RESPUESTA := 'OK. ENTREVISTA INTERNA [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;   
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_ENT_INT;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_PRO_CAP
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_PRO_CAP" (	
	TIPO 		      IN 	RC.PROCESO_CAPTACION.PC_TIPO%TYPE,
  F_INICIO      IN 	RC.PROCESO_CAPTACION.PC_F_INICIO%TYPE,
  COD_SEDE      IN 	RC.PROCESO_CAPTACION.PC_SEDE_CF%TYPE,
  DETALLES      IN 	RC.PROCESO_CAPTACION.PC_DETALLES%TYPE,
  F_FIN		      IN 	RC.PROCESO_CAPTACION.PC_F_FIN%TYPE,	
	COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.PROCESO_CAPTACION.PC_COD_PROC_CAP%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_PRO_CAP';
  PAR_ENTRADA := 'TIPO: ' || TIPO || ', FECHA DE INICIO: ' || F_INICIO || ', CODIGO DE SEDE: ' || COD_SEDE || ', DETALLES: ' || DETALLES || 
                     ',FECHA DE FIN: ' || F_FIN; 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF TIPO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL TIPO DE PROCESO DE CAPTACION';    
  ELSIF F_INICIO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA DE INICIO';
  ELSIF COD_SEDE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA SEDE ASOCIADA';
  ELSIF DETALLES IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LOS DETALLES DEL PROCESO DE CAPTACION';
  ELSIF UPPER(TIPO) NOT IN('PRENSA','RADIO','TV','INTERNET','CORREO','OTRO') THEN
    RESPUESTA := 'ERROR. EL TIPO DE PROCESO DE CAPTACION HA DE SER UNO DE LOS SIGUIENTES: PRENSA,RADIO,TV,INTERNET,CORREO,OTRO';
  ELSIF F_FIN IS NOT NULL AND F_INICIO > F_FIN THEN
    RESPUESTA := 'ERROR. LA FECHA DE FIN NO PUEDE SER ANTERIOR A LA DE INICIO';
  ELSE  
    -- Se controla que la sede exista
    SELECT COUNT(*) INTO CF_EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(COD_SEDE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(COD_SEDE);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;  
    
	INSERT INTO PROCESO_CAPTACION(				
    PC_TIPO,
    PC_F_INICIO,
    PC_F_FIN,
    PC_DETALLES,
    PC_SEDE_CF)
	VALUES(
		UPPER(TIPO),
		F_INICIO,
		F_FIN,
		DETALLES,
		UPPER(COD_SEDE))
  RETURNING PC_COD_PROC_CAP INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR EL PROCESO DE CAPTACION';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. PROCESO DE CAPTACION [' || COD_ASIGNADO || '] AÃ‘ADIDO CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_PRO_CAP;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_PROPUESTA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_PROPUESTA" (
	DETALLES      IN 	RC.PROPUESTA.PR_DETALLES%TYPE,
  COMERCIAL     IN 	RC.PROPUESTA.PR_COMERCIAL_CF%TYPE,
  CLIENTE       IN 	RC.PROPUESTA.PR_CLIENTE_CF%TYPE,
  IMPORTE	      IN 	RC.PROPUESTA.PR_IMPORTE%TYPE,
  ACEPTADA      IN 	RC.PROPUESTA.PR_ES_ACEPTADA%TYPE,
  F_PROP        IN 	RC.PROPUESTA.PR_F_PROPUESTA%TYPE,
  F_ACEPT       IN 	RC.PROPUESTA.PR_F_ACEPTACION%TYPE,  
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.PROPUESTA.PR_COD_PROPUESTA%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_PROPUESTA';
  PAR_ENTRADA := 'DETALLES: ' || DETALLES || ', CODIGO DE COMERCIAL: ' || COMERCIAL || ', CODIGO DE CLIENTE: ' || CLIENTE || ', IMPORTE: ' || IMPORTE || 
                 ', PROPUESTA ACEPTADA: ' || ACEPTADA || ', FECHA DE PROPUESTA: ' || F_PROP || ', FECHA DE ACEPTACION: ' || F_ACEPT;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF DETALLES IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LOS DETALLES DE LA PROPUESTA';    
  ELSIF COMERCIAL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL COMERCIAL';
  ELSIF CLIENTE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CLIENTE'; 
  ELSIF ACEPTADA IS NOT NULL AND UPPER(ACEPTADA) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI LA PROPUESTA HA SIDO ACEPTADA CON Y/N';
  ELSE  
    -- Se controla que comercial y cliente existen
    SELECT COUNT(*) INTO CF_EXISTE FROM COMERCIAL WHERE CO_COD_COMERCIAL=UPPER(COMERCIAL);    
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN COMERCIAL CON CODIGO ' || UPPER(COMERCIAL);      
    ELSE      
      SELECT COUNT(*) INTO CF_EXISTE FROM CLIENTE WHERE CL_COD_CLIENTE=UPPER(CLIENTE);
      IF CF_EXISTE = 0 THEN
        RESPUESTA := 'ERROR. NO EXISTE NINGUN CLIENTE CON CODIGO ' || UPPER(CLIENTE);
      END IF;
    END IF;  
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
     
	INSERT INTO PROPUESTA(    
    PR_DETALLES,
    PR_IMPORTE,
    PR_ES_ACEPTADA,        
    PR_COMERCIAL_CF,
    PR_CLIENTE_CF,
    PR_F_PROPUESTA,
    PR_F_ACEPTACION)
	VALUES(
		DETALLES,
		IMPORTE,
		UPPER(ACEPTADA),
		UPPER(COMERCIAL),
    UPPER(CLIENTE),    
    F_PROP,    
		F_ACEPT)
  RETURNING PR_COD_PROPUESTA INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA PROPUESTA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. PROPUESTA [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_PROPUESTA;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_PRO_SEL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_PRO_SEL" (		
  F_INICIO      IN 	RC.PROCESO_SELECCION.PS_F_INICIO%TYPE,
  COD_CLIENTE   IN 	RC.PROCESO_SELECCION.PS_CLIENTE_CF%TYPE,
  F_FIN         IN 	RC.PROCESO_SELECCION.PS_F_FIN%TYPE,
  COMENTARIOS   IN 	RC.PROCESO_SELECCION.PS_COMENTARIOS%TYPE,
	COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.PROCESO_SELECCION.PS_COD_PROC_SEL%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_PRO_SEL';
  PAR_ENTRADA := 'FECHA DE INICIO: ' || F_INICIO || ', FECHA DE FIN: ' || F_FIN || ', CODIGO DE CLIENTE: ' || COD_CLIENTE || ', COMENTARIOS: ' || COMENTARIOS;  
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF F_INICIO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA DE INICIO';
  ELSIF COD_CLIENTE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DEL CLIENTE';  
  ELSIF F_FIN IS NOT NULL AND F_INICIO > F_FIN THEN
    RESPUESTA := 'ERROR. LA FECHA DE FIN NO PUEDE SER ANTERIOR A LA DE INICIO';
  ELSE  
    -- Se controla que el cliente exista
    SELECT COUNT(*) INTO CF_EXISTE FROM CLIENTE WHERE CL_COD_CLIENTE=UPPER(COD_CLIENTE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN CLIENTE CON CODIGO ' || UPPER(COD_CLIENTE);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;  
    
	INSERT INTO PROCESO_SELECCION(				    
    PS_F_INICIO,
    PS_CLIENTE_CF,
    PS_F_FIN,
    PS_COMENTARIOS)
	VALUES(
		F_INICIO,
		UPPER(COD_CLIENTE),
		F_FIN,
		COMENTARIOS)
  RETURNING PS_COD_PROC_SEL INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR EL PROCESO DE SELECCION';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. PROCESO DE SELECCION [' || COD_ASIGNADO || '] AÃ‘ADIDO CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_PRO_SEL;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_SEDE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_SEDE" (	
	TELEFONO 		    IN 	RC.SEDE.SE_TELEFONO%TYPE,
	POBLACION 		  IN 	RC.SEDE.SE_POBLACION%TYPE,
	COD_POSTAL 		  IN 	RC.SEDE.SE_COD_POSTAL%TYPE,
	DIRECCION 		  IN 	RC.SEDE.SE_DIRECCION%TYPE,
	F_INAUGURACION 	IN 	RC.SEDE.SE_F_INAUGURACION%TYPE,
	RESPONSABLE 	  IN 	RC.SEDE.SE_RESPONSABLE%TYPE,
	COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		  OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  COD_ASIGNADO    RC.SEDE.SE_COD_SEDE%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_SEDE';
  PAR_ENTRADA := 'TELEFONO: ' || TELEFONO || ', POBLACION: ' || POBLACION || ', C.POSTAL: ' || COD_POSTAL || ', DIRECCION: ' || DIRECCION || 
                     ',FECHA INAUGURACION: ' || F_INAUGURACION || ', RESPONSABLE: ' || RESPONSABLE; 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF TELEFONO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NUMERO DE TELEFONO DE LA SEDE';    
  ELSIF POBLACION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA POBLACION DE LA SEDE';
  ELSIF COD_POSTAL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO POSTAL DE LA SEDE';
  ELSIF DIRECCION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA DIRECCION DE LA SEDE'; 
  ELSIF F_INAUGURACION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR UNA FECHA DE INAUGURACION';
  END IF;
  
  -- Se lanza una excepcion cuando falta algÃºn valor obligatorio
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;  
  END IF;
    
	INSERT INTO SEDE(		
		SE_TELEFONO,
		SE_POBLACION,
		SE_COD_POSTAL,
		SE_DIRECCION,
		SE_F_INAUGURACION,
		SE_RESPONSABLE)
	VALUES(
		TELEFONO,
		POBLACION,
		COD_POSTAL,
		DIRECCION,
		F_INAUGURACION,
		RESPONSABLE)
    RETURNING SE_COD_SEDE INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA SEDE';
    RAISE EXCEPCION;
  ELSE
    RESPUESTA := 'OK. SEDE [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
END PA_ALTA_SEDE;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_VACANTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_VACANTE" (	
  PROC_SEL        IN 	RC.VACANTE.VA_PROC_SEL_CF%TYPE,
	N_ESTUDIOS      IN 	RC.VACANTE.VA_NIVEL_ESTUDIOS%TYPE,
  N_PUESTOS       IN 	RC.VACANTE.VA_NUM_PUESTOS%TYPE,
  ESPECIALIZACION IN 	RC.VACANTE.VA_ESPECIALIZACION%TYPE,  
  COMPETENCIAS    IN 	VARCHAR2,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.VACANTE.VA_COD_VACANTE%TYPE;
  EXCEPCION       EXCEPTION;
  NUM_COMP        NUMBER;
  AUX_COMP        VARCHAR2(10);
  AUX_EXP         VARCHAR2(15);
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_VACANTE';
  PAR_ENTRADA := 'PROCESO DE SELECCION: ' || PROC_SEL || ' NIVEL DE ESTUDIOS: ' || N_ESTUDIOS || ', NUMERO DE PUESTOS: ' || N_PUESTOS || 
                 ', ESPECIALIZACION: ' || ESPECIALIZACION || ', COMPETENCIAS: ' || COMPETENCIAS;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF PROC_SEL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL PROCESO DE SELECCION';    
  ELSIF N_ESTUDIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NIVEL DE ESTUDIOS';   
  ELSIF N_PUESTOS IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL NUMERO DE PUESTOS';
  ELSIF UPPER(N_ESTUDIOS) NOT IN ('ESO','BACHILLERATO','FP','GRADO','MASTER','DOCTORADO') THEN
    RESPUESTA := 'ERROR. EL NIVEL DE ESTUDIOS DEBE SER ALGUNO ENTRE: ESO,BACHILLERATO,FP,GRADO,MASTER,DOCTORADO';
  ELSIF N_PUESTOS < 1 THEN
    RESPUESTA := 'ERROR. EL NUMERO DE PUESTOS HA DE SER AL MENOS 1';
  ELSE  
    -- Se controla que el proceso de seleccion exista
    SELECT COUNT(*) INTO CF_EXISTE FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL=UPPER(PROC_SEL);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE SELECCION CON CODIGO ' || UPPER(PROC_SEL);
    END IF;      
  END IF;
     
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
    SAVEPOINT inserta_vacante;
	INSERT INTO VACANTE(				        
    VA_PROC_SEL_CF,
    VA_NIVEL_ESTUDIOS,
    VA_ESPECIALIZACION,    
    VA_NUM_PUESTOS)
	VALUES(
		UPPER(PROC_SEL),
		UPPER(N_ESTUDIOS),
		ESPECIALIZACION,
    N_PUESTOS)
  RETURNING VA_COD_VACANTE INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA VACANTE';
    RAISE EXCEPCION;
  ELSE   
    -- se aÃ±aden las competencias. Si no son vÃ¡lidas se hace rollback
    IF COMPETENCIAS IS NOT NULL THEN
      NUM_COMP := REGEXP_COUNT(COMPETENCIAS, '<COMPETENCIA>',1,'i');
      FOR i IN 1..NUM_COMP LOOP          
        AUX_COMP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'), 
              REGEXP_INSTR(COMPETENCIAS,'</COMPETENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'));                  
        AUX_EXP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'), 
             REGEXP_INSTR(COMPETENCIAS,'</EXPERIENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'));
             
        -- Se comprueba que la competencia existe      
        SELECT COUNT(*) INTO CF_EXISTE FROM COMPETENCIA WHERE CP_COD_COMPETENCIA=UPPER(AUX_COMP);             
          IF CF_EXISTE = 0 THEN          
            RESPUESTA := 'ERROR. NO EXISTE NINGUNA COMPETENCIA CON CODIGO ' || UPPER(AUX_COMP);
            ROLLBACK TO inserta_vacante;
            RAISE EXCEPCION;
          ELSE
            IF UPPER(AUX_EXP) NOT IN ('ALTA','MEDIA','BAJA') THEN
              RESPUESTA := 'ERROR. LA EXPERIENCIA NO PUEDE SER ' || UPPER(AUX_EXP) || '. HA DE SER ALTA, MEDIA O BAJA.';
              ROLLBACK TO inserta_vacante;
              RAISE EXCEPCION;
            ELSE
              -- se asocia la competencia con la vacante            
              INSERT INTO COMPETENCIA_VACANTE (CV_COMPETENCIA_CF,CV_VACANTE_CF,CV_EXPERIENCIA)
                        VALUES(UPPER(AUX_COMP),COD_ASIGNADO,UPPER(AUX_EXP)); 
              -- Se comprueba que se ha introducido la nueva fila  
              IF SQL%ROWCOUNT != 1 THEN
                RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA COMPETENCIA ' || AUX_COMP || ' A LA VACANTE ' || COD_ASIGNADO;
                ROLLBACK TO inserta_vacante;
                RAISE EXCEPCION;            
              END IF; 
            END IF;
          END IF;
      END LOOP;    
    END IF;
    
    RESPUESTA := 'OK. VACANTE [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_VACANTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_ALTA_VISITA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_ALTA_VISITA" (	
	FECHA         IN 	RC.VISITA.VI_FECHA%TYPE,
  COMENTARIOS   IN 	RC.VISITA.VI_COMENTARIOS%TYPE,
  COMERCIAL     IN 	RC.VISITA.VI_COMERCIAL_CF%TYPE,
  CLIENTE       IN 	RC.VISITA.VI_CLIENTE_CF%TYPE,
  PROPUESTA     IN 	RC.VISITA.VI_PROPUESTA_CF%TYPE,
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.VISITA.VI_COD_VISITA%TYPE;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_ALTA_VISITA';
  PAR_ENTRADA := 'FECHA: ' || FECHA || ', COMENTARIOS: ' || COMENTARIOS || ', CODIGO DE COMERCIAL: ' || COMERCIAL || 
                 ', CODIGO DE CLIENTE: ' || CLIENTE || ', CODIGO DE PROPUESTA: ' || PROPUESTA;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF FECHA IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA FECHA';    
  ELSIF COMENTARIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR COMENTARIOS';
  ELSIF COMERCIAL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL COMERCIAL';
  ELSIF CLIENTE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CLIENTE';  
  ELSE      
    -- Se controla que comercial y cliente existen
    SELECT COUNT(*) INTO CF_EXISTE FROM COMERCIAL WHERE CO_COD_COMERCIAL=UPPER(COMERCIAL);    
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN COMERCIAL CON CODIGO ' || UPPER(COMERCIAL);      
    ELSE      
      SELECT COUNT(*) INTO CF_EXISTE FROM CLIENTE WHERE CL_COD_CLIENTE=UPPER(CLIENTE);
      IF CF_EXISTE = 0 THEN
        RESPUESTA := 'ERROR. NO EXISTE NINGUN CLIENTE CON CODIGO ' || UPPER(CLIENTE);
      END IF;
    END IF;  
  END IF;
  
  -- si se indica una propuesta, se comprueba que existe
  IF PROPUESTA IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM PROPUESTA WHERE PR_COD_PROPUESTA=UPPER(PROPUESTA);    
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA PROPUESTA CON CODIGO ' || UPPER(PROPUESTA);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
     
	INSERT INTO VISITA(    
    VI_FECHA,    
    VI_COMENTARIOS,
    VI_COMERCIAL_CF,
    VI_CLIENTE_CF,
    VI_PROPUESTA_CF)
	VALUES(
		FECHA,
		COMENTARIOS,
		UPPER(COMERCIAL),		
    UPPER(CLIENTE),    
    UPPER(PROPUESTA))
  RETURNING VI_COD_VISITA INTO COD_ASIGNADO;
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA VISITA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. VISITA [' || COD_ASIGNADO || '] AÃ‘ADIDA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_ALTA_VISITA;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_CANDIDATO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_CANDIDATO" (	
	CANDIDATO       IN 	RC.CANDIDATO.CA_COD_CANDIDATO%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_CANDIDATO';
  PAR_ENTRADA := 'CODIGO DE CANDIDATO: ' || CANDIDATO;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que el candidato exista
  SELECT COUNT(*) INTO EXISTE FROM CANDIDATO WHERE CA_COD_CANDIDATO=UPPER(CANDIDATO);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUN CANDIDATO CON CODIGO ' || UPPER(CANDIDATO);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM CANDIDATO
  WHERE CA_COD_CANDIDATO = UPPER(CANDIDATO);
	    
  -- Se comprueba que se ha borrado el candidato  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR EL CANDIDATO';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. CANDIDATO [' || UPPER(CANDIDATO) || '] ELIMINADO CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_CANDIDATO;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_CLIENTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_CLIENTE" (	
	CLIENTE         IN 	RC.CLIENTE.CL_COD_CLIENTE%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_CLIENTE';
  PAR_ENTRADA := 'CODIGO DE CLIENTE: ' || CLIENTE;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que el cliente exista
  SELECT COUNT(*) INTO EXISTE FROM CLIENTE WHERE CL_COD_CLIENTE=UPPER(CLIENTE);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUN CLIENTE CON CODIGO ' || UPPER(CLIENTE);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM CLIENTE
  WHERE CL_COD_CLIENTE = UPPER(CLIENTE);
	    
  -- Se comprueba que se ha borrado el candidato  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR EL CLIENTE';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. CLIENTE [' || UPPER(CLIENTE) || '] ELIMINADO CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_CLIENTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_COMERCIAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_COMERCIAL" (	
	COMERCIAL       IN 	RC.COMERCIAL.CO_COD_COMERCIAL%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_COMERCIAL';
  PAR_ENTRADA := 'CODIGO DE COMERCIAL: ' || COMERCIAL;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que el comercial exista
  SELECT COUNT(*) INTO EXISTE FROM COMERCIAL WHERE CO_COD_COMERCIAL=UPPER(COMERCIAL);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUN COMERCIAL CON CODIGO ' || UPPER(COMERCIAL);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM COMERCIAL
  WHERE CO_COD_COMERCIAL = UPPER(COMERCIAL);
	    
  -- Se comprueba que se ha borrado el comercial  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR EL COMERCIAL';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. COMERCIAL [' || UPPER(COMERCIAL) || '] ELIMINADO CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_COMERCIAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_COMPETENCIA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_COMPETENCIA" (	
	COMPETENCIA     IN 	RC.COMPETENCIA.CP_COD_COMPETENCIA%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_COMPETENCIA';
  PAR_ENTRADA := 'CODIGO DE COMPETENCIA: ' || COMPETENCIA;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la competencia exista
  SELECT COUNT(*) INTO EXISTE FROM COMPETENCIA WHERE CP_COD_COMPETENCIA=UPPER(COMPETENCIA);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA COMPETENCIA CON CODIGO ' || UPPER(COMPETENCIA);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM COMPETENCIA
  WHERE CP_COD_COMPETENCIA = UPPER(COMPETENCIA);
	    
  -- Se comprueba que se ha borrado la competencia  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA COMPETENCIA';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. COMPETENCIA [' || UPPER(COMPETENCIA) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_COMPETENCIA;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_ENT_EXT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_ENT_EXT" (	
	ENTREVISTA      IN 	RC.ENTREVISTA_EXTERNA.EE_COD_ENTREVISTA%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_ENT_EXT';
  PAR_ENTRADA := 'CODIGO DE ENTREVISTA EXTERNA: ' || ENTREVISTA;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la entrevista exista
  SELECT COUNT(*) INTO EXISTE FROM ENTREVISTA_EXTERNA WHERE EE_COD_ENTREVISTA=UPPER(ENTREVISTA);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA ENTREVISTA EXTERNA CON CODIGO ' || UPPER(ENTREVISTA);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM ENTREVISTA_EXTERNA
  WHERE EE_COD_ENTREVISTA = UPPER(ENTREVISTA);
	    
  -- Se comprueba que se ha borrado la entrevista
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA ENTREVISTA EXTERNA';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. ENTREVISTA EXTERNA [' || UPPER(ENTREVISTA) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_ENT_EXT;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_ENT_INT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_ENT_INT" (	
	ENTREVISTA      IN 	RC.ENTREVISTA_INTERNA.EI_COD_ENTREVISTA%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_ENT_INT';
  PAR_ENTRADA := 'CODIGO DE ENTREVISTA INTERNA: ' || ENTREVISTA;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la entrevista exista
  SELECT COUNT(*) INTO EXISTE FROM ENTREVISTA_INTERNA WHERE EI_COD_ENTREVISTA=UPPER(ENTREVISTA);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA ENTREVISTA INTERNA CON CODIGO ' || UPPER(ENTREVISTA);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM ENTREVISTA_INTERNA
  WHERE EI_COD_ENTREVISTA = UPPER(ENTREVISTA);
	    
  -- Se comprueba que se ha borrado la entrevista
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA ENTREVISTA INTERNA';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. ENTREVISTA INTERNA [' || UPPER(ENTREVISTA) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_ENT_INT;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_PROC_CAP
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_PROC_CAP" (	
	PROC_CAP        IN 	RC.PROCESO_CAPTACION.PC_COD_PROC_CAP%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_PROC_CAP';
  PAR_ENTRADA := 'CODIGO DE PROCESO DE CAPTACION: ' || PROC_CAP;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que el proceso de captacion exista
  SELECT COUNT(*) INTO EXISTE FROM PROCESO_CAPTACION WHERE PC_COD_PROC_CAP=UPPER(PROC_CAP);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE CAPTACION CON CODIGO ' || UPPER(PROC_CAP);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM PROCESO_CAPTACION
  WHERE PC_COD_PROC_CAP = UPPER(PROC_CAP);
	    
  -- Se comprueba que se ha borrado el proceso de captacion
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR EL PROCESO DE CAPTACION';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. PROCESO DE CAPTACION [' || UPPER(PROC_CAP) || '] ELIMINADO CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_PROC_CAP;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_PROC_SEL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_PROC_SEL" (	
	PROC_SEL        IN 	RC.PROCESO_SELECCION.PS_COD_PROC_SEL%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_PROC_SEL';
  PAR_ENTRADA := 'CODIGO DE PROCESO DE SELECCION: ' || PROC_SEL;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que el proceso de seleccion exista
  SELECT COUNT(*) INTO EXISTE FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL=UPPER(PROC_SEL);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE SELECCION CON CODIGO ' || UPPER(PROC_SEL);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM PROCESO_SELECCION
  WHERE PS_COD_PROC_SEL = UPPER(PROC_SEL);
	    
  -- Se comprueba que se ha borrado el proceso de seleccion
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR EL PROCESO DE SELECCION';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. PROCESO DE SELECCION [' || UPPER(PROC_SEL) || '] ELIMINADO CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_PROC_SEL;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_PROPUESTA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_PROPUESTA" (	
	PROPUESTA       IN 	RC.PROPUESTA.PR_COD_PROPUESTA%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_PROPUESTA';
  PAR_ENTRADA := 'CODIGO DE PROPUESTA: ' || PROPUESTA;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la propuesta exista
  SELECT COUNT(*) INTO EXISTE FROM PROPUESTA WHERE PR_COD_PROPUESTA=UPPER(PROPUESTA);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA PROPUESTA CON CODIGO ' || UPPER(PROPUESTA);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM PROPUESTA
  WHERE PR_COD_PROPUESTA = UPPER(PROPUESTA);
	    
  -- Se comprueba que se ha borrado la propuesta
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA PROPUESTA';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. PROPUESTA [' || UPPER(PROPUESTA) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_PROPUESTA;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_SEDE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_SEDE" (	
	SEDE       IN 	RC.SEDE.SE_COD_SEDE%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_SEDE';
  PAR_ENTRADA := 'CODIGO DE SEDE: ' || SEDE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la sede exista
  SELECT COUNT(*) INTO EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(SEDE);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(SEDE);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM SEDE
  WHERE SE_COD_SEDE = UPPER(SEDE);
	    
  -- Se comprueba que se ha borrado la sede
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA SEDE';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. SEDE [' || UPPER(SEDE) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_SEDE;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_VACANTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_VACANTE" (	
	VACANTE         IN 	RC.VACANTE.VA_COD_VACANTE%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_VACANTE';
  PAR_ENTRADA := 'CODIGO DE VACANTE: ' || VACANTE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la vacante exista
  SELECT COUNT(*) INTO EXISTE FROM VACANTE WHERE VA_COD_VACANTE=UPPER(VACANTE);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA VACANTE CON CODIGO ' || UPPER(VACANTE);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM VACANTE
  WHERE VA_COD_VACANTE = UPPER(VACANTE);
	    
  -- Se comprueba que se ha borrado la vacante
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA VACANTE';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. VACANTE [' || UPPER(VACANTE) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_VACANTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_BAJA_VISITA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_BAJA_VISITA" (	
	VISITA          IN 	RC.VISITA.VI_COD_VISITA%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  EXISTE          NUMBER;  
  EXCEPCION       EXCEPTION;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_BAJA_VISITA';
  PAR_ENTRADA := 'CODIGO DE VISITA: ' || VISITA;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que la visita exista
  SELECT COUNT(*) INTO EXISTE FROM VISITA WHERE VI_COD_VISITA=UPPER(VISITA);
  IF EXISTE = 0 THEN
    RESPUESTA := 'ERROR. NO EXISTE NINGUNA VISITA CON CODIGO ' || UPPER(VISITA);    
    RAISE EXCEPCION;
  END IF;
     
	DELETE FROM VISITA
  WHERE VI_COD_VISITA = UPPER(VISITA);
	    
  -- Se comprueba que se ha borrado la visita
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO BORRAR LA VISITA';
    RAISE EXCEPCION;
  END IF;
    
  RESPUESTA := 'OK. VISITA [' || UPPER(VISITA) || '] ELIMINADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_BAJA_VISITA;

/
--------------------------------------------------------
--  DDL for Procedure PA_CALCULA_PROP_COMERCIAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CALCULA_PROP_COMERCIAL" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  
  CURSOR RANKING IS
    SELECT PR_COMERCIAL_CF AS COMERCIAL, SUM(PR_IMPORTE) AS TOTAL
    FROM PROPUESTA  
    WHERE PR_ES_ACEPTADA = 'Y'
    GROUP BY PR_COMERCIAL_CF;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CALCULA_PROP_COMERCIAL';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  FOR i IN RANKING
  LOOP
    UPDATE COMERCIAL
    SET CO_IMP_PROPUESTAS = i.TOTAL
    WHERE CO_COD_COMERCIAL = i.COMERCIAL;
    
    IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO ACTUALIZAR LA FILA DEL COMERCIAL ' || i.COMERCIAL;
    RAISE EXCEPCION;    
    END IF;
  END LOOP;
     
  RESPUESTA := 'OK. IMPORTE TOTAL DE PROPUESTAS DE COMERCIALES ACTUALIZADO';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION    
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CALCULA_PROP_COMERCIAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_CANDIDATO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_CANDIDATO" (	
  COD_CANDIDATO   IN  RC.CANDIDATO.CA_COD_CANDIDATO%TYPE,
	APELLIDOS       IN 	RC.CANDIDATO.CA_APELLIDOS%TYPE,  
  N_ESTUDIOS      IN  RC.CANDIDATO.CA_NIVEL_ESTUDIOS%TYPE,
  SEDE            IN  RC.CANDIDATO.CA_SEDE_CF%TYPE,    
  COMPETENCIA     IN  RC.COMPETENCIA.CP_COD_COMPETENCIA%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_CANDIDATO';
  PAR_ENTRADA := 'CODIGO DE CANDIDATO: ' || COD_CANDIDATO || ', APELLIDOS:' || APELLIDOS || ', NIVEL DE ESTUDIOS: ' || N_ESTUDIOS || ', SEDE: ' || SEDE || 
                 ', COMPETENCIA: ' || COMPETENCIA;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_CANDIDATO IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CANDIDATO
      WHERE UPPER(CA_COD_CANDIDATO) = UPPER(COD_CANDIDATO);
  ELSIF APELLIDOS IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CANDIDATO
      WHERE UPPER(CA_APELLIDOS) LIKE '%' || UPPER(APELLIDOS) || '%';
  ELSIF N_ESTUDIOS IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CANDIDATO
      WHERE UPPER(CA_NIVEL_ESTUDIOS) = UPPER(N_ESTUDIOS);
  ELSIF SEDE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CANDIDATO
      WHERE UPPER(CA_SEDE_CF) = UPPER(SEDE);
  ELSIF COMPETENCIA IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CANDIDATO
      WHERE UPPER(CA_COD_CANDIDATO) IN (
        SELECT CC_CANDIDATO_CF FROM COMPETENCIA_CANDIDATO WHERE CC_COMPETENCIA_CF = UPPER(COMPETENCIA));
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM CANDIDATO;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE CANDIDATOS REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_CANDIDATO;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_CLIENTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_CLIENTE" (	
  COD_CLIENTE     IN  RC.CLIENTE.CL_COD_CLIENTE%TYPE,
	NOMBRE          IN 	RC.CLIENTE.CL_NOMBRE%TYPE,  
  POBLACION       IN  RC.CLIENTE.CL_POBLACION%TYPE,
  SEDE            IN  RC.CLIENTE.CL_SEDE_CF%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_CLIENTE';
  PAR_ENTRADA := 'CODIGO DE CLIENTE: ' || COD_CLIENTE || ', NOMBRE:' || NOMBRE || ', POBLACION: ' || POBLACION || ', SEDE: ' || SEDE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_CLIENTE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CLIENTE
      WHERE UPPER(CL_COD_CLIENTE) = UPPER(COD_CLIENTE);
  ELSIF NOMBRE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CLIENTE
      WHERE UPPER(CL_NOMBRE) LIKE '%' || UPPER(NOMBRE) || '%';
  ELSIF POBLACION IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CLIENTE
      WHERE UPPER(CL_POBLACION) = UPPER(POBLACION);
  ELSIF SEDE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM CLIENTE
      WHERE UPPER(CL_SEDE_CF) = UPPER(SEDE);
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM CLIENTE;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE CLIENTES REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_CLIENTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_COMERCIAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_COMERCIAL" (	
  COD_COMERCIAL   IN  RC.COMERCIAL.CO_COD_COMERCIAL%TYPE,
	NOMBRE          IN 	RC.COMERCIAL.CO_NOMBRE%TYPE,  
  APELLIDOS       IN 	RC.COMERCIAL.CO_APELLIDOS%TYPE,  
  SEDE            IN 	RC.COMERCIAL.CO_SEDE_CF%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_COMERCIAL';
  PAR_ENTRADA := 'CODIGO DE COMERCIAL: ' || COD_COMERCIAL || ', NOMBRE:' || NOMBRE || ', APELLIDOS: ' || APELLIDOS || ', SEDE: ' || SEDE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_COMERCIAL IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM COMERCIAL
      WHERE UPPER(CO_COD_COMERCIAL) = UPPER(COD_COMERCIAL);
  ELSIF NOMBRE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM COMERCIAL
      WHERE UPPER(CO_NOMBRE) LIKE '%' || UPPER(NOMBRE) || '%';
  ELSIF APELLIDOS IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM COMERCIAL
      WHERE UPPER(CO_APELLIDOS) = UPPER(APELLIDOS);
  ELSIF SEDE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM COMERCIAL
      WHERE UPPER(CO_SEDE_CF) = UPPER(SEDE);
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM COMERCIAL;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE COMERCIALES REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_COMERCIAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_COMPETENCIA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_COMPETENCIA" (	
  COD_COMPETENCIA IN  RC.COMPETENCIA.CP_COD_COMPETENCIA%TYPE,
	NOMBRE          IN 	RC.COMPETENCIA.CP_NOMBRE%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_COMPETENCIA';
  PAR_ENTRADA := 'CODIGO DE COMPETENCIA: ' || COD_COMPETENCIA || ', NOMBRE:' || NOMBRE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_COMPETENCIA IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM COMPETENCIA
      WHERE UPPER(CP_COD_COMPETENCIA) = UPPER(COD_COMPETENCIA);
  ELSIF NOMBRE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM COMPETENCIA
      WHERE UPPER(CP_NOMBRE) LIKE '%' || UPPER(NOMBRE) || '%';
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM COMPETENCIA;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE COMPETENCIAS REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_COMPETENCIA;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_ENT_EXT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_ENT_EXT" (	
  COD_ENT_EXT     IN  RC.ENTREVISTA_EXTERNA.EE_COD_ENTREVISTA%TYPE,
  CANDIDATO       IN  RC.ENTREVISTA_EXTERNA.EE_CANDIDATO_CF%TYPE,
  PROC_SEL        IN  RC.ENTREVISTA_EXTERNA.EE_PROC_SEL_CF%TYPE,
  VACANTE         IN  RC.VACANTE.VA_COD_VACANTE%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_ENT_EXT';
  PAR_ENTRADA := 'CODIGO DE ENTREVISTA EXTERNA: ' || COD_ENT_EXT || ', CANDIDATO:' || CANDIDATO || ', PROCESO DE SELECCION: ' || PROC_SEL || ', VACANTE: ' || VACANTE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_ENT_EXT IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_EXTERNA
      WHERE UPPER(EE_COD_ENTREVISTA) = UPPER(COD_ENT_EXT);
  ELSIF CANDIDATO IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_EXTERNA
      WHERE UPPER(EE_CANDIDATO_CF) = UPPER(CANDIDATO);
  ELSIF PROC_SEL IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_EXTERNA
      WHERE UPPER(EE_PROC_SEL_CF) = UPPER(PROC_SEL);
  ELSIF VACANTE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_EXTERNA
      WHERE UPPER(EE_COD_ENTREVISTA) IN (
        SELECT ESV_ENT_EXT_CF FROM ENTREVISTA_SELECCION_VACANTE
        WHERE ESV_VACANTE_CF = UPPER(VACANTE));
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_EXTERNA;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE ENTREVISTAS EXTERNAS REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_ENT_EXT;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_ENT_INT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_ENT_INT" (	
  COD_ENT_INT     IN  RC.ENTREVISTA_INTERNA.EI_COD_ENTREVISTA%TYPE,
  CANDIDATO       IN  RC.ENTREVISTA_INTERNA.EI_CANDIDATO_CF%TYPE,
  SEDE            IN  RC.ENTREVISTA_INTERNA.EI_SEDE_CF%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_ENT_INT';
  PAR_ENTRADA := 'CODIGO DE ENTREVISTA INTERNA: ' || COD_ENT_INT || ', CANDIDATO:' || CANDIDATO || ', SEDE: ' || SEDE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_ENT_INT IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_INTERNA
      WHERE UPPER(EI_COD_ENTREVISTA) = UPPER(COD_ENT_INT);
  ELSIF CANDIDATO IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_INTERNA
      WHERE UPPER(EI_CANDIDATO_CF) = UPPER(CANDIDATO);
  ELSIF SEDE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_INTERNA
      WHERE UPPER(EI_SEDE_CF) = UPPER(SEDE);
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM ENTREVISTA_INTERNA;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE ENTREVISTAS INTERNAS REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_ENT_INT;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_PRO_CAP
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_PRO_CAP" (	
  COD_PROC_CAP    IN  RC.PROCESO_CAPTACION.PC_COD_PROC_CAP%TYPE,
  SEDE            IN  RC.PROCESO_CAPTACION.PC_SEDE_CF%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_PRO_CAP';
  PAR_ENTRADA := 'CODIGO DE PROCESO DE CAPTACIÃ“N: ' || COD_PROC_CAP || ', SEDE: ' || SEDE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_PROC_CAP IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROCESO_CAPTACION
      WHERE UPPER(PC_COD_PROC_CAP) = UPPER(COD_PROC_CAP);  
  ELSIF SEDE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROCESO_CAPTACION
      WHERE UPPER(PC_SEDE_CF) = UPPER(SEDE);
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM PROCESO_CAPTACION;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE PROCESOS DE CAPTACION REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_PRO_CAP;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_PROPUESTA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_PROPUESTA" (	
  COD_PROPUESTA   IN  RC.PROPUESTA.PR_COD_PROPUESTA%TYPE,
  COMERCIAL       IN  RC.PROPUESTA.PR_COMERCIAL_CF%TYPE,
  CLIENTE         IN  RC.PROPUESTA.PR_CLIENTE_CF%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_PROPUESTA';
  PAR_ENTRADA := 'CODIGO DE PROPUESTA: ' || COD_PROPUESTA || ', COMERCIAL: ' || COMERCIAL || ', CLIENTE: ' || CLIENTE;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_PROPUESTA IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROPUESTA
      WHERE UPPER(PR_COD_PROPUESTA) = UPPER(COD_PROPUESTA);  
  ELSIF COMERCIAL IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROPUESTA
      WHERE UPPER(PR_COMERCIAL_CF) = UPPER(COMERCIAL);
  ELSIF CLIENTE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROPUESTA
      WHERE UPPER(PR_CLIENTE_CF) = UPPER(CLIENTE);  
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM PROPUESTA;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE PROPUESTAS REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_PROPUESTA;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_PRO_SEL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_PRO_SEL" (	
  COD_PROC_SEL    IN  RC.PROCESO_SELECCION.PS_COD_PROC_SEL%TYPE,
  CLIENTE         IN  RC.PROCESO_SELECCION.PS_CLIENTE_CF%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_PRO_SEL';
  PAR_ENTRADA := 'CODIGO DE PROCESO DE SELECCIÃ“N: ' || COD_PROC_SEL || ', CLIENTE: ' || CLIENTE;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_PROC_SEL IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROCESO_SELECCION
      WHERE UPPER(PS_COD_PROC_SEL) = UPPER(COD_PROC_SEL);  
  ELSIF CLIENTE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM PROCESO_SELECCION
      WHERE UPPER(PS_CLIENTE_CF) = UPPER(CLIENTE);
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM PROCESO_SELECCION;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE PROCESOS DE SELECCION REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_PRO_SEL;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_SEDE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_SEDE" (	
  COD_SEDE        IN  RC.SEDE.SE_COD_SEDE%TYPE,
  POBLACION       IN  RC.SEDE.SE_POBLACION%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_SEDE';
  PAR_ENTRADA := 'CODIGO DE SEDE: ' || COD_SEDE || ', POBLACION: ' || POBLACION;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_SEDE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM SEDE
      WHERE UPPER(SE_COD_SEDE) = UPPER(COD_SEDE);  
  ELSIF POBLACION IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM SEDE
      WHERE UPPER(SE_POBLACION) LIKE '%' || UPPER(POBLACION) || '%';
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM SEDE;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE SEDES REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_SEDE;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_VACANTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_VACANTE" (	
  COD_VACANTE     IN  RC.VACANTE.VA_COD_VACANTE%TYPE,
  N_ESTUDIOS      IN  RC.VACANTE.VA_NIVEL_ESTUDIOS%TYPE,
  COMPETENCIA     IN  VARCHAR2,
  PROC_SEL        IN  RC.VACANTE.VA_PROC_SEL_CF%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_VACANTE';
  PAR_ENTRADA :=  'CODIGO DE VACANTE: ' || COD_VACANTE || ', NIVEL DE ESTUDIOS: ' || N_ESTUDIOS || 
                  ', COMPETENCIA: ' || COMPETENCIA|| ', PROCESO DE SELECCION: ' || PROC_SEL;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_VACANTE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VACANTE
      WHERE UPPER(VA_COD_VACANTE) = UPPER(COD_VACANTE);  
  ELSIF N_ESTUDIOS IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VACANTE
      WHERE UPPER(VA_NIVEL_ESTUDIOS) = UPPER(N_ESTUDIOS);      
  ELSIF COMPETENCIA IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VACANTE
      WHERE UPPER(VA_COD_VACANTE) IN (
        SELECT CV_VACANTE_CF FROM COMPETENCIA_VACANTE WHERE CV_COMPETENCIA_CF = UPPER(COMPETENCIA)); 
  ELSIF PROC_SEL IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VACANTE
        WHERE VA_PROC_SEL_CF = UPPER(PROC_SEL); 
  ELSE
    OPEN RESULTADO FOR
      SELECT * FROM VACANTE;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE VACANTES REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_VACANTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_CONS_VISITA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_CONS_VISITA" (	
  COD_VISITA      IN  RC.VISITA.VI_COD_VISITA%TYPE,
  COMERCIAL       IN  RC.VISITA.VI_COMERCIAL_CF%TYPE,
  CLIENTE         IN  RC.VISITA.VI_CLIENTE_CF%TYPE,
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
  RESULTADO       OUT SYS_REFCURSOR
  )	
  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  RESPUESTA 	  	RC.LOG.LOG_RSP%TYPE;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_CONS_VISITA';
  PAR_ENTRADA := 'CODIGO DE VISITA: ' || COD_VISITA || ', COMERCIAL: ' || COMERCIAL || ', CLIENTE: ' || CLIENTE;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se hace la consulta en funciÃ³n de que filtro se ha indicado
  IF COD_VISITA IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VISITA
      WHERE UPPER(VI_COD_VISITA) = UPPER(COD_VISITA);  
  ELSIF COMERCIAL IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VISITA
      WHERE UPPER(VI_COMERCIAL_CF) = UPPER(COMERCIAL);
  ELSIF CLIENTE IS NOT NULL THEN
    OPEN RESULTADO FOR
      SELECT * FROM VISITA
      WHERE UPPER(VI_CLIENTE_CF) = UPPER(CLIENTE);  
  ELSE 
    OPEN RESULTADO FOR
      SELECT * FROM VISITA;
  END IF; 
  
  RESPUESTA := 'OK. CONSULTA DE VISITAS REALIZADA CORRECTAMENTE';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_CONS_VISITA;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_CAN_INACT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_CAN_INACT" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  CAN_TOTAL       RC.DW_RATIO_CAN_INACTIVOS.RCI_CAN_TOTALES%TYPE;
  CAN_ACTIVOS       RC.DW_RATIO_CAN_INACTIVOS.RCI_CAN_INACTIVOS%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_CAN_INACT';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  
  -- Se toma el dato de candidatos totales del sistema
  SELECT COUNT(*) 
  INTO CAN_TOTAL     
  FROM CANDIDATO;
  
  -- Se calcula el nÃºmero de candidatos que han sido seleccionados en alguna entrevista externa
  SELECT COUNT(DISTINCT CA_COD_CANDIDATO)
  INTO CAN_ACTIVOS
  FROM CANDIDATO C
  LEFT JOIN ENTREVISTA_EXTERNA EE
  ON C.CA_COD_CANDIDATO = EE.EE_CANDIDATO_CF
  WHERE EE.EE_SELECCIONADO = 'Y';

  -- Se inserta la fila con el calculo en la tabla del DW
  INSERT INTO DW_RATIO_CAN_INACTIVOS
    (RCI_FECHA, RCI_CAN_INACTIVOS,RCI_CAN_TOTALES)
     VALUES(SYSTIMESTAMP,CAN_TOTAL-CAN_ACTIVOS,CAN_TOTAL);
  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_CAN_INACT;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_CAPTACION_HIST_EXITO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_CAPTACION_HIST_EXITO" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  MEJOR_PRO_CAP   RC.DW_CAPTACION_HIST_EXITO.CHE_PROC_CAP_CF%TYPE;
  NUM_CONTRATOS   RC.DW_CAPTACION_HIST_EXITO.CHE_NUM_CAN%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_CAPTACION_HIST_EXITO';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
   
  -- Se calcula el proceso de captacion con mas candidatos contratados, y el numero de estos
  SELECT PROCESO_CAPTACION, CONTRATADOS
  INTO MEJOR_PRO_CAP, NUM_CONTRATOS
  FROM (
      SELECT C.CA_PROC_CAPTACION_CF AS PROCESO_CAPTACION, COUNT(DISTINCT EE.EE_CANDIDATO_CF) AS CONTRATADOS
      FROM ENTREVISTA_EXTERNA EE
      JOIN CANDIDATO C
      ON C.CA_COD_CANDIDATO=EE.EE_CANDIDATO_CF
      WHERE EE_SELECCIONADO = 'Y' AND C.CA_PROC_CAPTACION_CF IS NOT NULL
      GROUP BY C.CA_PROC_CAPTACION_CF
      ORDER BY CONTRATADOS DESC
      )  
  WHERE ROWNUM = 1;
  
  -- Se inserta la fila con el calculo en la tabla del DW
  INSERT INTO DW_CAPTACION_HIST_EXITO
    (CHE_FECHA, CHE_PROC_CAP_CF,CHE_NUM_CAN)
     VALUES(SYSTIMESTAMP,MEJOR_PRO_CAP, NUM_CONTRATOS);
  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_CAPTACION_HIST_EXITO;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_CAPTACION_TOP_ANUAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_CAPTACION_TOP_ANUAL" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  MEJOR_PRO_CAP   RC.DW_CAPTACION_HIST_EXITO.CHE_PROC_CAP_CF%TYPE;
  NUM_CONTRATOS   RC.DW_CAPTACION_HIST_EXITO.CHE_NUM_CAN%TYPE;
  ANYO            NUMBER;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_CAPTACION_TOP_ANUAL';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  ANYO := EXTRACT (YEAR FROM SYSDATE);
     
  -- Se calcula el proceso de captacion con mas candidatos contratados durante el aÃ±o actual, y el numero de estos
  SELECT PROCESO_CAPTACION, CONTRATADOS
  INTO MEJOR_PRO_CAP, NUM_CONTRATOS
  FROM (
      SELECT C.CA_PROC_CAPTACION_CF AS PROCESO_CAPTACION, COUNT(DISTINCT EE.EE_CANDIDATO_CF) AS CONTRATADOS
      FROM ENTREVISTA_EXTERNA EE
      JOIN CANDIDATO C
      ON C.CA_COD_CANDIDATO=EE.EE_CANDIDATO_CF
      WHERE EE_SELECCIONADO = 'Y' AND C.CA_PROC_CAPTACION_CF IS NOT NULL 
        AND EXTRACT(YEAR FROM EE.EE_FECHA)=EXTRACT(YEAR FROM SYSDATE)
      GROUP BY C.CA_PROC_CAPTACION_CF
      ORDER BY CONTRATADOS DESC
      )  
  WHERE ROWNUM = 1;
  
  IF SQL%ROWCOUNT != 0 THEN
      -- Primero se borra la fila correspondiente al aÃ±o actual que se va a actualizar
      DELETE FROM DW_CAPTACION_TOP_ANUAL
      WHERE ctA_anyo = ANYO;
      
      -- Se inserta la fila con el calculo en la tabla del DW
      INSERT INTO DW_CAPTACION_TOP_ANUAL
        (CTA_ANYO, CTA_PROCESO_CAPTACION_CF,CTA_NUM_CONTRA)
        VALUES(ANYO,MEJOR_PRO_CAP, NUM_CONTRATOS);
  
      IF SQL%ROWCOUNT != 1 THEN
        RESPUESTA := 'ERROR. NO SE HA PODIDO AÑADIR LA FILA';
        RAISE EXCEPCION;
      ELSE    
        RESPUESTA := 'OK. 1 FILA AÑADIDA A DW';
        COD_SALIDA := 0;
      END IF;  
  END IF;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_CAPTACION_TOP_ANUAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_CLIENTE_PROP_RECHAZA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_CLIENTE_PROP_RECHAZA" (
  ANYO	  IN 	NUMBER
  )
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  TOP_CLIENTE     RC.dw_cliente_prop_rechazadas.cpr_cliente_cf%TYPE;
  NUM_RECHAZOS    RC.dw_cliente_prop_rechazadas.cpr_num_rechazos%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_CLIENTE_PROP_RECHAZA';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
     
  -- Se calcula el cliente que mas propuestas ha rechazado, y el nÃºmero de estas
  SELECT CLIENTE, RECHAZOS
  INTO TOP_CLIENTE, NUM_RECHAZOS
  FROM (
        SELECT PR_CLIENTE_CF AS CLIENTE, COUNT(*) AS RECHAZOS
        FROM PROPUESTA
        WHERE PR_ES_ACEPTADA = 'N' AND EXTRACT(YEAR FROM PR_F_PROPUESTA) = ANYO
        GROUP BY EXTRACT(YEAR FROM PR_F_PROPUESTA), PR_CLIENTE_CF
        ORDER BY COUNT(*) DESC
      )  
  WHERE ROWNUM = 1;
  
  IF SQL%ROWCOUNT = 1 THEN
      -- Primero se borra la fila correspondiente al aÃ±o que se va a actualizar
      DELETE FROM DW_CLIENTE_PROP_RECHAZADAS
      WHERE cpr_anyo = ANYO
      ;
      -- Se inserta la fila con el calculo en la tabla del DW
      INSERT INTO DW_CLIENTE_PROP_RECHAZADAS
        (CPR_ANYO, CPR_CLIENTE_CF,CPR_NUM_RECHAZOS)
        VALUES(ANYO,TOP_CLIENTE, NUM_RECHAZOS);
  
      IF SQL%ROWCOUNT != 1 THEN
        RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
        RAISE EXCEPCION;
      ELSE    
        RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
        COD_SALIDA := 0;
      END IF;
  ELSE
    RESPUESTA := 'NO SE HAN ENCONTRADO PROPUESTAS RECHAZADAS PARA EL AÃ‘O ' || ANYO;
    COD_SALIDA := 0;
  END IF;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_CLIENTE_PROP_RECHAZA;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_CLIENTE_TOP_CONTRATOS
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_CLIENTE_TOP_CONTRATOS" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  TOP_CLIENTE     RC.DW_CLIENTE_TOP_CONTRATACIONES.CTC_COD_CLIENTE_CF%TYPE;
  NUM_CONTRATOS   RC.DW_CLIENTE_TOP_CONTRATACIONES.CTC_NUM_CONTRA%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_CLIENTE_TOP_CONTRATOS';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
   
  -- Se calcula el cliente que mas candidatos ha contratado, y el numero de estos
  SELECT TOPCLIENTE, CONTRATADOS
  INTO TOP_CLIENTE, NUM_CONTRATOS
  FROM (
      SELECT PS.PS_CLIENTE_CF AS TOPCLIENTE, COUNT(DISTINCT EE.EE_CANDIDATO_CF) AS CONTRATADOS
      FROM ENTREVISTA_EXTERNA EE
      JOIN PROCESO_SELECCION PS
      ON EE.EE_PROC_SEL_CF=PS.PS_COD_PROC_SEL
      WHERE EE_SELECCIONADO ='Y'
      GROUP BY PS.PS_CLIENTE_CF
      ORDER BY CONTRATADOS DESC
      )  
  WHERE ROWNUM = 1;
  
  -- Se inserta la fila con el calculo en la tabla del DW
  INSERT INTO DW_CLIENTE_TOP_CONTRATACIONES
    (CTC_FECHA, CTC_COD_CLIENTE_CF,CTC_NUM_CONTRA)
     VALUES(SYSTIMESTAMP,TOP_CLIENTE, NUM_CONTRATOS);
  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_CLIENTE_TOP_CONTRATOS;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_COMERCIAL_TOP_VISITAS
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_COMERCIAL_TOP_VISITAS" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  TOP_COMERCIAL   RC.dw_comercial_top_visitas.ctv_comercial_cf%TYPE;
  NUM_VISITAS     RC.dw_comercial_top_visitas.ctv_num_visitas%TYPE;
  ANYO            NUMBER;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_COMERCIAL_TOP_VISITAS';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  ANYO := EXTRACT(YEAR FROM SYSDATE);
  
     
  -- Se calcula el comercial que mÃ¡s visitas ha realizado en el aÃ±o actual, y el numero de estas
  SELECT TOPCOMERCIAL, VISITAS
  INTO TOP_COMERCIAL, NUM_VISITAS
  FROM (
      SELECT VI_COMERCIAL_CF TOPCOMERCIAL, COUNT(*) AS VISITAS
      FROM VISITA
      WHERE EXTRACT(YEAR FROM vi_fecha) = EXTRACT(YEAR FROM SYSDATE)
      GROUP BY vi_comercial_cf
      ORDER BY COUNT(*) DESC, TOP_COMERCIAL
      )  
  WHERE ROWNUM = 1;
  -- Primero se borra la fila correspondiente al aÃ±o actual que se va a actualizar
  DELETE FROM DW_COMERCIAL_TOP_VISITAS
  WHERE ctv_anyo = ANYO
  ;
  -- Se inserta la fila con el calculo en la tabla del DW
  INSERT INTO DW_COMERCIAL_TOP_VISITAS(CTV_ANYO, CTV_COMERCIAL_CF,CTV_NUM_VISITAS)
    VALUES(ANYO,TOP_COMERCIAL, NUM_VISITAS);
  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_COMERCIAL_TOP_VISITAS;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_ENT_INT_ANYO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_ENT_INT_ANYO" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_ENT_INT_ANYO';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Primero se vacÃ­a la tabla de estadÃ­sticas  
  DELETE FROM DW_ENT_INT_ANYO;
  -- Se insertan las filas tras recalcularlas
  INSERT INTO DW_ENT_INT_ANYO(EIA_ANYO,EIA_NUM_ENT_INT)
    SELECT EXTRACT(YEAR FROM EI_FECHA) AS EIA_ANYO, COUNT(*) AS EIA_NUM_ENT_INT
    FROM ENTREVISTA_INTERNA
    GROUP BY EXTRACT(YEAR FROM EI_FECHA);
     
  RESPUESTA := 'OK. ' || SQL%ROWCOUNT || ' FILAS AÃ‘ADIDAS A DW';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION    
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_ENT_INT_ANYO;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_IMP_PROP_ACEPTADAS
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_IMP_PROP_ACEPTADAS" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_IMP_PROP_ACEPTADAS';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Primero se vacÃ­a la tabla de estadÃ­sticas  
  DELETE FROM DW_IMP_PROPUESTAS_ACEPTADAS;
  -- Se insertan las filas tras recalcularlas
  INSERT INTO DW_IMP_PROPUESTAS_ACEPTADAS(IPA_ANYO,IPA_IMPORTE_TOTAL)
    SELECT EXTRACT(YEAR FROM PR_F_ACEPTACION) AS IPA_ANYO, SUM(PR_IMPORTE) AS IPA_IMPORTE_TOTAL
    FROM PROPUESTA
    WHERE pr_f_aceptacion IS NOT NULL
    GROUP BY EXTRACT(YEAR FROM PR_F_ACEPTACION);    
     
  RESPUESTA := 'OK. ' || SQL%ROWCOUNT || ' FILAS AÃ‘ADIDAS A DW';
  COD_SALIDA := 0;
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION    
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_IMP_PROP_ACEPTADAS;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_LIDER_COMERCIAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_LIDER_COMERCIAL" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  COMERCIAL_TOP   RC.dw_lider_comercial.lc_comercial_cf%TYPE;
  PROP_ACEPTADAS  RC.dw_lider_comercial.lc_prop_exito%TYPE;
  PROP_TOTALES    RC.dw_lider_comercial.lc_prop_totales%TYPE;
  RATIO           RC.dw_lider_comercial.lc_ratio%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_LIDER_COMERCIAL';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;  
   
  -- Se calcula el con mayor nÃºmero de propuestas aceptadas sobre las presentadas, y el ratio entre ellas
  SELECT TOPCOMERCIAL,ACEPTADAS,TOTAL,RATIO
  INTO COMERCIAL_TOP,PROP_ACEPTADAS,PROP_TOTALES, RATIO
  FROM (
      SELECT P.PR_COMERCIAL_CF AS TOPCOMERCIAL, COUNT(*) AS ACEPTADAS, T.TOTAL AS TOTAL, COUNT(*)/T.TOTAL AS RATIO
      FROM PROPUESTA P
      JOIN
      -- NUMERO TOTAL DE PROPUESTAS POR COMERCIAL
        (SELECT PR_COMERCIAL_CF AS COM, COUNT(*) AS TOTAL 
        FROM PROPUESTA
        GROUP BY PR_COMERCIAL_CF) T
        ON P.PR_COMERCIAL_CF = T.COM
        WHERE P.PR_ES_ACEPTADA = 'Y'
        GROUP BY P.PR_COMERCIAL_CF,T.TOTAL
        ORDER BY RATIO DESC, TOTAL DESC, PR_COMERCIAL_CF
      )  
  WHERE ROWNUM = 1;
  
  -- Se inserta la fila con el calculo en la tabla del DW
  INSERT INTO DW_LIDER_COMERCIAL
    (LC_FECHA, LC_COMERCIAL_CF,LC_PROP_EXITO,LC_PROP_TOTALES,LC_RATIO)
     VALUES(SYSTIMESTAMP,COMERCIAL_TOP,PROP_ACEPTADAS,PROP_TOTALES,RATIO);
  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_LIDER_COMERCIAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_RATIO_PRO_SEL_EXITO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_RATIO_PRO_SEL_EXITO" 
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  PROCESOS_ANYO   RC.dw_ratio_pro_sel_exito.rps_num_pro_sel%TYPE;
  PROCESOS_EXITO  RC.dw_ratio_pro_sel_exito.rps_num_pro_exito%TYPE;
  RATIO           RC.dw_ratio_pro_sel_exito.rps_ratio_anual%TYPE;
    
BEGIN    
  PROCEDIMIENTO := 'PA_DW_RATIO_PRO_SEL_EXITO';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;

  --Primero se limpia la tabla antes de actualizarla
  DELETE FROM DW_RATIO_PRO_SEL_EXITO;
  
  --Se calculan e insertan los datos 
  INSERT INTO DW_RATIO_PRO_SEL_EXITO(RPS_ANYO,RPS_NUM_PRO_EXITO,RPS_NUM_PRO_SEL,RPS_RATIO_ANUAL)
    SELECT  EXTRACT(YEAR FROM EE.EE_FECHA) AS ANYO, COUNT(DISTINCT EE.EE_PROC_SEL_CF) AS PROCESOS_EXITO, 
        EE2.PROCESOS_POR_ANYO, COUNT(DISTINCT EE.EE_PROC_SEL_CF)/EE2.PROCESOS_POR_ANYO AS RATIO
    FROM ENTREVISTA_EXTERNA EE
    JOIN
    (
      SELECT EXTRACT(YEAR FROM EE_FECHA) AS ANYO, COUNT(DISTINCT EE_PROC_SEL_CF) AS PROCESOS_POR_ANYO
      FROM ENTREVISTA_EXTERNA
      GROUP BY EXTRACT(YEAR FROM EE_FECHA)
    ) EE2
    ON EXTRACT(YEAR FROM EE.EE_FECHA)=EE2.ANYO
    WHERE EE.EE_SELECCIONADO = 'Y'
    GROUP BY EXTRACT(YEAR FROM EE.EE_FECHA),EE2.PROCESOS_POR_ANYO
    ORDER BY ANYO DESC;
  
  RESPUESTA := 'OK. ' || SQL%ROWCOUNT || ' FILAS AÃ‘ADIDAS A DW';
  COD_SALIDA := 0;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_RATIO_PRO_SEL_EXITO;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_SEDE_MENOS_ENTREVISTAS
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_SEDE_MENOS_ENTREVISTAS" 	  
AS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  SEDE            RC.dw_sede_menos_entrevistas.sme_sede_cf%TYPE;
  NUM_ENTREVISTAS RC.dw_sede_menos_entrevistas.sme_num_entr%TYPE;
  ANYO            NUMBER;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_SEDE_MENOS_ENTREVISTAS';
  PAR_ENTRADA := 'N/A';                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  ANYO := EXTRACT(YEAR FROM SYSDATE);
  
  
  -- Se calcula la sede con un menor nÃºmero de entrevistas, y el numero de estas
  SELECT SEDE, ENTREVISTAS
  INTO SEDE, NUM_ENTREVISTAS
  FROM (
      SELECT SE_COD_SEDE AS SEDE, NVL(ENT,0) AS ENTREVISTAS
      FROM SEDE
      LEFT JOIN
        (SELECT EI_SEDE_CF, COUNT(DISTINCT EI_COD_ENTREVISTA)AS ENT
          FROM ENTREVISTA_INTERNA
          WHERE EXTRACT(YEAR FROM EI_FECHA) = ANYO
          GROUP BY EI_SEDE_CF) E
          ON SEDE.SE_COD_SEDE= E.EI_SEDE_CF
          ORDER BY ENTREVISTAS, SEDE
      )  
  WHERE ROWNUM = 1;
  -- Primero se borra la fila correspondiente al aÃ±o actual, ya que se va a actualizar
      DELETE FROM DW_SEDE_MENOS_ENTREVISTAS
      WHERE SME_ANYO = ANYO;
  -- Se insertan las filas tras recalcularlas
    INSERT INTO DW_SEDE_MENOS_ENTREVISTAS(SME_ANYO,SME_SEDE_CF,SME_NUM_ENTR)
    VALUES(ANYO,SEDE,NUM_ENTREVISTAS);
    
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_SEDE_MENOS_ENTREVISTAS;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_TOP10_ESTUDIOS
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_TOP10_ESTUDIOS" (	
	ANYO	  IN 	NUMBER
  )	  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  ESTUDIO1        RC.dw_top_ten_estudios.tte_niv_est_1%TYPE;
  ESPEC1          RC.dw_top_ten_estudios.tte_espec_1%TYPE;
  ESTUDIO2        RC.dw_top_ten_estudios.tte_niv_est_2%TYPE;
  ESPEC2          RC.dw_top_ten_estudios.tte_espec_2%TYPE;
  ESTUDIO3        RC.dw_top_ten_estudios.tte_niv_est_3%TYPE;
  ESPEC3          RC.dw_top_ten_estudios.tte_espec_3%TYPE;
  ESTUDIO4        RC.dw_top_ten_estudios.tte_niv_est_4%TYPE;
  ESPEC4          RC.dw_top_ten_estudios.tte_espec_4%TYPE;
  ESTUDIO5        RC.dw_top_ten_estudios.tte_niv_est_5%TYPE;
  ESPEC5          RC.dw_top_ten_estudios.tte_espec_5%TYPE;
  ESTUDIO6        RC.dw_top_ten_estudios.tte_niv_est_6%TYPE;
  ESPEC6          RC.dw_top_ten_estudios.tte_espec_6%TYPE;
  ESTUDIO7        RC.dw_top_ten_estudios.tte_niv_est_7%TYPE;
  ESPEC7          RC.dw_top_ten_estudios.tte_espec_7%TYPE;
  ESTUDIO8        RC.dw_top_ten_estudios.tte_niv_est_8%TYPE;
  ESPEC8          RC.dw_top_ten_estudios.tte_espec_8%TYPE;
  ESTUDIO9        RC.dw_top_ten_estudios.tte_niv_est_9%TYPE;
  ESPEC9          RC.dw_top_ten_estudios.tte_espec_9%TYPE;
  ESTUDIO10       RC.dw_top_ten_estudios.tte_niv_est_10%TYPE;
  ESPEC10         RC.dw_top_ten_estudios.tte_espec_10%TYPE;
    
  CURSOR RANKING IS 
    SELECT ROWNUM,ESTUDIOS,ESPEC
    FROM (
      SELECT EXTRACT(YEAR FROM PS_F_INICIO) AS ANYO, VA_NIVEL_ESTUDIOS AS ESTUDIOS, VA_ESPECIALIZACION AS ESPEC, COUNT(*) AS NUM
      FROM VACANTE
      JOIN PROCESO_SELECCION
      ON PROCESO_SELECCION.PS_COD_PROC_SEL=VACANTE.VA_PROC_SEL_CF
      WHERE EXTRACT(YEAR FROM PS_F_INICIO) = ANYO
      GROUP BY EXTRACT(YEAR FROM PS_F_INICIO),VA_NIVEL_ESTUDIOS,VA_ESPECIALIZACION
      ORDER BY ANYO DESC, NUM DESC    
      )  
    WHERE ROWNUM < 11;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_TOP10_ESTUDIOS';
  PAR_ENTRADA := ANYO;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
    
  -- Se recorre la tabla aÃ±adiendo
  FOR i IN RANKING 
  LOOP
    CASE
      WHEN i.ROWNUM = 1 THEN ESTUDIO1 := i.ESTUDIOS;
      WHEN i.ROWNUM = 2 THEN ESTUDIO2 := i.ESTUDIOS;
      WHEN i.ROWNUM = 3 THEN ESTUDIO3 := i.ESTUDIOS;
      WHEN i.ROWNUM = 4 THEN ESTUDIO4 := i.ESTUDIOS;
      WHEN i.ROWNUM = 5 THEN ESTUDIO5 := i.ESTUDIOS;
      WHEN i.ROWNUM = 6 THEN ESTUDIO6 := i.ESTUDIOS;
      WHEN i.ROWNUM = 7 THEN ESTUDIO7 := i.ESTUDIOS;
      WHEN i.ROWNUM = 8 THEN ESTUDIO8 := i.ESTUDIOS;
      WHEN i.ROWNUM = 9 THEN ESTUDIO9 := i.ESTUDIOS;
      WHEN i.ROWNUM = 10 THEN ESTUDIO10 := i.ESTUDIOS;
    END CASE;
    CASE
      WHEN i.ROWNUM = 1 THEN ESPEC1 := i.ESPEC;
      WHEN i.ROWNUM = 2 THEN ESPEC2 := i.ESPEC;
      WHEN i.ROWNUM = 3 THEN ESPEC3 := i.ESPEC;
      WHEN i.ROWNUM = 4 THEN ESPEC4 := i.ESPEC;
      WHEN i.ROWNUM = 5 THEN ESPEC5 := i.ESPEC;
      WHEN i.ROWNUM = 6 THEN ESPEC6 := i.ESPEC;
      WHEN i.ROWNUM = 7 THEN ESPEC7 := i.ESPEC;
      WHEN i.ROWNUM = 8 THEN ESPEC8 := i.ESPEC;
      WHEN i.ROWNUM = 9 THEN ESPEC9 := i.ESPEC;
      WHEN i.ROWNUM = 10 THEN ESPEC10 := i.ESPEC;
    END CASE;
  END LOOP;
    
  -- Se borra la fila que corresponde al aÃ±o q estamos actualizando
  DELETE FROM DW_TOP_TEN_ESTUDIOS
  WHERE TTE_ANYO = ANYO;
  -- Se inserta el top actualizado para el aÃ±o que corresponda
  INSERT INTO DW_TOP_TEN_ESTUDIOS (
      TTE_ANYO, 
      TTE_NIV_EST_1, 
      TTE_ESPEC_1,  
      TTE_NIV_EST_2, 
      TTE_ESPEC_2, 
      TTE_NIV_EST_3, 
      TTE_ESPEC_3, 
      TTE_NIV_EST_4, 
      TTE_ESPEC_4, 
      TTE_NIV_EST_5, 
      TTE_ESPEC_5, 
      TTE_NIV_EST_6, 
      TTE_ESPEC_6, 
      TTE_NIV_EST_7, 
      TTE_ESPEC_7, 
      TTE_NIV_EST_8, 
      TTE_ESPEC_8, 
      TTE_NIV_EST_9, 
      TTE_ESPEC_9, 
      TTE_NIV_EST_10, 
      TTE_ESPEC_10)
  VALUES(
      ANYO,
      ESTUDIO1,
      ESPEC1,
      ESTUDIO2,
      ESPEC2,
      ESTUDIO3,
      ESPEC3,
      ESTUDIO4,
      ESPEC4,
      ESTUDIO5,
      ESPEC5,
      ESTUDIO6,
      ESPEC6,
      ESTUDIO7,
      ESPEC7,
      ESTUDIO8,
      ESPEC8,
      ESTUDIO9,
      ESPEC9,
      ESTUDIO10,
      ESPEC10);

  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_TOP10_ESTUDIOS;

/
--------------------------------------------------------
--  DDL for Procedure PA_DW_TOP5_COMPETENCIAS
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_DW_TOP5_COMPETENCIAS" (	
	ANYO	  IN 	NUMBER
  )	  
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;   
  COD_SALIDA      RC.LOG.LOG_COD_SALIDA%TYPE;
  RESPUESTA       RC.LOG.LOG_RSP%TYPE;
  EXCEPCION       EXCEPTION;
  COMPETENCIA1    RC.dw_top_five_competencias.tfc_comp_1%TYPE;
  COMPETENCIA2    RC.dw_top_five_competencias.tfc_comp_2%TYPE;
  COMPETENCIA3    RC.dw_top_five_competencias.tfc_comp_3%TYPE;
  COMPETENCIA4    RC.dw_top_five_competencias.tfc_comp_4%TYPE;
  COMPETENCIA5    RC.dw_top_five_competencias.tfc_comp_5%TYPE;

  
    
  CURSOR RANKING IS 
   SELECT ROWNUM,COMPETENCIA
    FROM (
      SELECT EXTRACT(YEAR FROM PS_F_INICIO)AS ANYO, CP_NOMBRE AS COMPETENCIA, COUNT(*) AS NUM
      FROM VACANTE V
      JOIN PROCESO_SELECCION PS
      ON PS.PS_COD_PROC_SEL=V.VA_PROC_SEL_CF
      JOIN COMPETENCIA_VACANTE CV
      ON cv.cv_vacante_cf = v.va_cod_vacante
      JOIN COMPETENCIA C
      ON c.cp_cod_competencia = cv.cv_competencia_cf
      WHERE EXTRACT(YEAR FROM PS_F_INICIO) = ANYO
      GROUP BY EXTRACT(YEAR FROM PS_F_INICIO),CP_NOMBRE
      ORDER BY ANYO DESC, NUM DESC    
      )  
    WHERE ROWNUM < 6;
  
BEGIN    
  PROCEDIMIENTO := 'PA_DW_TOP5_COMPETENCIAS';
  PAR_ENTRADA := ANYO;                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
    
  -- Se recorre la tabla aÃ±adiendo
  FOR i IN RANKING 
  LOOP
    CASE
      WHEN i.ROWNUM = 1 THEN COMPETENCIA1 := i.COMPETENCIA;
      WHEN i.ROWNUM = 2 THEN COMPETENCIA2 := i.COMPETENCIA;
      WHEN i.ROWNUM = 3 THEN COMPETENCIA3 := i.COMPETENCIA;
      WHEN i.ROWNUM = 4 THEN COMPETENCIA4 := i.COMPETENCIA;
      WHEN i.ROWNUM = 5 THEN COMPETENCIA5 := i.COMPETENCIA;      
    END CASE;
  END LOOP;
    
  -- Se borra la fila que corresponde al aÃ±o q estamos actualizando
  DELETE FROM DW_TOP_FIVE_COMPETENCIAS
  WHERE tfc_anyo = ANYO;
  -- Se inserta el top actualizado para el aÃ±o que corresponda
  INSERT INTO DW_TOP_FIVE_COMPETENCIAS (
      TFC_ANYO, 
      TFC_COMP_1, 
      TFC_COMP_2, 
      TFC_COMP_3, 
      TFC_COMP_4, 
      TFC_COMP_5)
  VALUES(
      ANYO,
      COMPETENCIA1,
      COMPETENCIA2,
      COMPETENCIA3,
      COMPETENCIA4,
      COMPETENCIA5
      );

  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA FILA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. 1 FILA AÃ‘ADIDA A DW';
    COD_SALIDA := 0;
  END IF;  
  PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);  
  
  -- Gestion de excepciones
  EXCEPTION 
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_DW_TOP5_COMPETENCIAS;

/

--------------------------------------------------------
--  DDL for Procedure PA_MODIF_CANDIDATO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_CANDIDATO" (	
  COD_CANDIDATO   IN  RC.CANDIDATO.CA_COD_CANDIDATO%TYPE,
	TFNO   	        IN 	RC.CANDIDATO.CA_TELEFONO%TYPE,
  N_ESTUDIOS      IN  RC.CANDIDATO.CA_NIVEL_ESTUDIOS%TYPE,
  BUSCA_TRABAJO   IN  RC.CANDIDATO.CA_BUSCA_TRABAJO%TYPE,  
  EMAIL 	        IN 	RC.CANDIDATO.CA_EMAIL%TYPE,
  ESPECIALIZACION IN 	RC.CANDIDATO.CA_ESPECIALIZACION%TYPE,  
  COMPETENCIAS    IN  VARCHAR2,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  COD_ASIGNADO    RC.CANDIDATO.CA_COD_CANDIDATO%TYPE;
  EXCEPCION       EXCEPTION;
  NUM_COMP        NUMBER;
  AUX_COMP        VARCHAR2(10);
  AUX_EXP         VARCHAR2(15);
  CAMPOS          VARCHAR2(200);
  VALORES         VARCHAR2(1000);
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_CANDIDATO';
  PAR_ENTRADA := 'CODIGO DE CANDIDATO: ' || COD_CANDIDATO || ', TELEFONO:' || TFNO || ', E-MAIL: ' || EMAIL || ', NIVEL DE ESTUDIOS: ' || N_ESTUDIOS || 
                 ', ESPECIALIZACION: ' || ESPECIALIZACION || ', BUSCANDO TRABAJO: ' || BUSCA_TRABAJO || ', COMPETENCIAS: ' || COMPETENCIAS;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_CANDIDATO IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DEL CANDIDATO';    
  ELSIF BUSCA_TRABAJO IS NOT NULL AND UPPER(BUSCA_TRABAJO) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI EL CANDIDATO BUSCA TRABAJO CON Y/N'; 
  ELSE
  -- Se controla que el candidato exista
    SELECT COUNT(*) INTO CF_EXISTE FROM CANDIDATO WHERE CA_COD_CANDIDATO=UPPER(COD_CANDIDATO);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN CANDIDATO CON CODIGO ' || UPPER(COD_CANDIDATO);
    END IF;      
  END IF;
     
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
	SAVEPOINT actualiza_candidato;
	UPDATE CANDIDATO
  SET   CA_TELEFONO         = NVL(TFNO,CA_TELEFONO),
        CA_NIVEL_ESTUDIOS   = NVL(N_ESTUDIOS,CA_NIVEL_ESTUDIOS),
        CA_BUSCA_TRABAJO    = NVL(UPPER(BUSCA_TRABAJO), CA_BUSCA_TRABAJO),
        CA_EMAIL            = NVL(EMAIL, CA_EMAIL),
        CA_ESPECIALIZACION  = NVL(ESPECIALIZACION, CA_ESPECIALIZACION)
  WHERE CA_COD_CANDIDATO    = UPPER(COD_CANDIDATO);
 
    
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR EL CANDIDATO';
    RAISE EXCEPCION;
  ELSE   
    -- se modifican las competencias. Si no son vÃ¡lidas se hace rollback
    IF COMPETENCIAS IS NOT NULL THEN
      -- primero se borran las competencias existentes del candidato, para despues introducir las nuevas
      DELETE FROM COMPETENCIA_CANDIDATO WHERE CC_CANDIDATO_CF = UPPER(COD_CANDIDATO);            
      NUM_COMP := REGEXP_COUNT(COMPETENCIAS, '<COMPETENCIA>',1,'i');    
      FOR i IN 1..NUM_COMP LOOP          
        AUX_COMP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'), 
              REGEXP_INSTR(COMPETENCIAS,'</COMPETENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'));                  
        AUX_EXP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'), 
             REGEXP_INSTR(COMPETENCIAS,'</EXPERIENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'));                       
        -- Se comprueba que la competencia existe      
        SELECT COUNT(*) INTO CF_EXISTE FROM COMPETENCIA WHERE CP_COD_COMPETENCIA=UPPER(AUX_COMP);    
          IF CF_EXISTE = 0 THEN          
            RESPUESTA := 'ERROR. NO EXISTE NINGUNA COMPETENCIA CON CODIGO ' || UPPER(AUX_COMP);
            ROLLBACK TO actualiza_candidato;
            RAISE EXCEPCION;          
          ELSE             
            -- se asocia la competencia con el candidato
            IF UPPER(AUX_EXP) = 'ALTA' OR UPPER(AUX_EXP) = 'MEDIA' OR UPPER(AUX_EXP) = 'BAJA' THEN
              INSERT INTO COMPETENCIA_CANDIDATO (CC_COMPETENCIA_CF,CC_CANDIDATO_CF,CC_EXPERIENCIA)
                VALUES(UPPER(AUX_COMP),UPPER(COD_CANDIDATO),UPPER(AUX_EXP));
            ELSE 
              RESPUESTA := 'ERROR. LA EXPERIENCIA NO PUEDE SER ' || UPPER(AUX_EXP);
              ROLLBACK TO actualiza_candidato;
              RAISE EXCEPCION; 
            END IF;
            -- Se comprueba que se ha introducido la nueva fila  
            IF SQL%ROWCOUNT != 1 THEN
              RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA COMPETENCIA ' || UPPER(AUX_COMP) || ' AL CANDIDATO ' || UPPER(COD_CANDIDATO);
              ROLLBACK TO actualiza_candidato;
              RAISE EXCEPCION;            
            END IF; 
          END IF;
      END LOOP;    
    END IF;
    
    RESPUESTA := 'OK. CANDIDATO [' || UPPER(COD_CANDIDATO) || '] MODIFICADO CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_CANDIDATO;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_CLIENTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_CLIENTE" (
  COD_CLIENTE   IN  RC.CLIENTE.CL_COD_CLIENTE%TYPE,
	NOMBRE	      IN 	RC.CLIENTE.CL_NOMBRE%TYPE,
  POBLACION     IN 	RC.CLIENTE.CL_POBLACION%TYPE,
  C_POSTAL      IN 	RC.CLIENTE.CL_COD_POSTAL%TYPE,
  DIRECCION     IN 	RC.CLIENTE.CL_DIRECCION%TYPE,
  TFNO		      IN 	RC.CLIENTE.CL_TELEFONO%TYPE,  
  CONTACTO      IN 	RC.CLIENTE.CL_CONTACTO%TYPE,
  TFNO_CONT     IN 	RC.CLIENTE.CL_TFNO_CONTACTO%TYPE,
  EMAIL_CONT    IN 	RC.CLIENTE.CL_EMAIL_CONTACTO%TYPE,  
	COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_CLIENTE';
  PAR_ENTRADA := 'NOMBRE: ' || NOMBRE || ', POBLACION: ' || POBLACION || ', CODIGO POSTAL: ' || C_POSTAL || ', DIRECCION: ' || DIRECCION || 
                 ', TELEFONO: ' || TFNO || ', CONTACTO: ' || CONTACTO || ', TELEFONO-PERSONA CONTACTO: ' || TFNO_CONT || 
                 ', EMAIL-PERSONA CONTACTO: ' || EMAIL_CONT;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_CLIENTE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DEL CLIENTE';    
  ELSE  
    -- Se controla que el cliente exista
    SELECT COUNT(*) INTO CF_EXISTE FROM CLIENTE WHERE CL_COD_CLIENTE=UPPER(COD_CLIENTE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN CLIENTE CON CODIGO ' || UPPER(COD_CLIENTE);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
            
  UPDATE CLIENTE
  SET   CL_NOMBRE           = NVL(NOMBRE,CL_NOMBRE),
        CL_POBLACION        = NVL(POBLACION,CL_POBLACION),
        CL_COD_POSTAL       = NVL(C_POSTAL, CL_COD_POSTAL),
        CL_DIRECCION        = NVL(DIRECCION, CL_DIRECCION),
        CL_TELEFONO         = NVL(TFNO, CL_TELEFONO),
        CL_CONTACTO         = NVL(CONTACTO, CL_CONTACTO),
        CL_TFNO_CONTACTO    = NVL(TFNO_CONT, CL_TFNO_CONTACTO),
        CL_EMAIL_CONTACTO   = NVL(EMAIL_CONT, CL_EMAIL_CONTACTO)        
  WHERE CL_COD_CLIENTE      = UPPER(COD_CLIENTE);
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR EL CLIENTE';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. CLIENTE [' || UPPER(COD_CLIENTE) || '] MODIFICADO CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_CLIENTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_COMERCIAL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_COMERCIAL" (	
  COD_COMERCIAL IN  RC.COMERCIAL.CO_COD_COMERCIAL%TYPE,
	TFNO          IN 	RC.COMERCIAL.CO_TELEFONO%TYPE,  
  EMAIL	        IN 	RC.COMERCIAL.CO_EMAIL%TYPE,  
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_COMERCIAL';
  PAR_ENTRADA := 'CODIGO DE COMERCIAL: ' || COD_COMERCIAL || ', TELEFONO: ' || TFNO || ', E-MAIL: ' || EMAIL;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_COMERCIAL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DEL COMERCIAL';    
  ELSE  
    -- Se controla que el comercial exista
    SELECT COUNT(*) INTO CF_EXISTE FROM COMERCIAL WHERE CO_COD_COMERCIAL=UPPER(COD_COMERCIAL);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN COMERCIAL CON CODIGO ' || UPPER(COD_COMERCIAL);
    END IF;      
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
     
	UPDATE COMERCIAL
  SET   CO_TELEFONO         = NVL(TFNO,CO_TELEFONO),        
        CO_EMAIL            = NVL(EMAIL, CO_EMAIL)
  WHERE CO_COD_COMERCIAL    = UPPER(COD_COMERCIAL);
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR EL COMERCIAL';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. COMERCIAL [' || UPPER(COD_COMERCIAL) || '] MODIFICADO CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_COMERCIAL;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_COMPETENCIA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_COMPETENCIA" (	
  COD_COMPETENCIA   IN  RC.COMPETENCIA.CP_COD_COMPETENCIA%TYPE,
	DESCRIPCION       IN 	RC.COMPETENCIA.CP_DESCRIPCION%TYPE,    
  COD_SALIDA		    OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		    OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_COMPETENCIA';
  PAR_ENTRADA := 'CODIGO DE COMPETENCIA: ' || COD_COMPETENCIA || ', DESCRIPCION: ' || DESCRIPCION;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_COMPETENCIA IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA COMPETENCIA'; 
  ELSIF DESCRIPCION IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR UNA DESCRIPCION';
  ELSE  
    -- Se controla que la competencia exista
    SELECT COUNT(*) INTO CF_EXISTE FROM COMPETENCIA WHERE CP_COD_COMPETENCIA=UPPER(COD_COMPETENCIA);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA COMPETENCIA CON CODIGO ' || UPPER(COD_COMPETENCIA);
    END IF;      
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
     
	UPDATE COMPETENCIA
  SET   CP_DESCRIPCION  = DESCRIPCION
  WHERE CP_COD_COMPETENCIA  = UPPER(COD_COMPETENCIA);
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA COMPETENCIA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. COMPETENCIA [' || UPPER(COD_COMPETENCIA) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_COMPETENCIA;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_ENT_EXT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_ENT_EXT" (	
  COD_ENT_EXT     IN  RC.ENTREVISTA_EXTERNA.EE_COD_ENTREVISTA%TYPE,
  FECHA           IN  RC.ENTREVISTA_EXTERNA.EE_FECHA%TYPE,
  PROC_SEL        IN  RC.ENTREVISTA_EXTERNA.EE_PROC_SEL_CF%TYPE,
  COMENTARIOS     IN  RC.ENTREVISTA_EXTERNA.EE_COMENTARIOS%TYPE,
  SELECCIONADO    IN  RC.ENTREVISTA_EXTERNA.EE_SELECCIONADO%TYPE,
  DESCARTADO      IN  RC.ENTREVISTA_EXTERNA.EE_DESCARTADO%TYPE,
  VACANTES        IN  VARCHAR2,    
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;  
  EXCEPCION       EXCEPTION;
  NUM_VAC         NUMBER;
  AUX_VAC         VARCHAR2(10);
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_ENT_EXT';
  PAR_ENTRADA := 'CODIGO DE ENTREVISTA EXTERNA: ' || COD_ENT_EXT || ', FECHA:' || FECHA || ', PROCESO DE SELECCION: ' || PROC_SEL || 
                 ', COMENTARIOS: ' || COMENTARIOS || ', SELECCIONADO: ' || SELECCIONADO || ', DESCARTADO: ' || DESCARTADO || ', VACANTE(S): ' || VACANTES;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_ENT_EXT IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA ENTREVISTA EXTERNA';
  ELSIF PROC_SEL IS NOT NULL AND VACANTES IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR LA NUEVA VACANTE(S) SI SE INDICA UN PROCESO DE SELECCION DISTINTO';
  ELSIF SELECCIONADO IS NOT NULL AND UPPER(SELECCIONADO) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI EL CANDIDATO HA SIDO SELECCIONADO CON Y/N';
  ELSIF DESCARTADO IS NOT NULL AND UPPER(DESCARTADO) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI EL CANDIDATO HA SIDO DESCARTADO CON Y/N';
  -- Se comprueba que se cumplen las restricciones de integridad 
  ELSIF UPPER(SELECCIONADO) = 'Y' AND UPPER(DESCARTADO) ='Y' THEN
    RESPUESTA := 'ERROR. NO ES POSIBLE SELECCIONAR A UN CANDIDATO Y DESCARTARLO A LA VEZ';    
  ELSIF UPPER(DESCARTADO) = 'Y' AND COMENTARIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES NECESARIO AÃ‘ADIR COMENTARIOS CUANDO SE DESCARTA PERMANENTEMENTE A UN CANDIDATO';       
  ELSE
  -- Se controla que la entrevista externa y el proceso de seleccion existan
    SELECT COUNT(*) INTO CF_EXISTE FROM ENTREVISTA_EXTERNA WHERE EE_COD_ENTREVISTA=UPPER(COD_ENT_EXT);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA ENTREVISTA EXTERNA CON CODIGO ' || UPPER(COD_ENT_EXT);
    ELSIF PROC_SEL IS NOT NULL THEN
      SELECT COUNT(*) INTO CF_EXISTE FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL=UPPER(PROC_SEL);
      IF CF_EXISTE = 0 THEN
        RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE SELECCION CON CODIGO ' || UPPER(PROC_SEL);
      END IF;
    END IF;      
    
  END IF;  
  
  IF UPPER(DESCARTADO) ='Y' AND SELECCIONADO IS NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM ENTREVISTA_EXTERNA WHERE EE_COD_ENTREVISTA=UPPER(COD_ENT_EXT) AND EE_SELECCIONADO = 'Y';
    IF CF_EXISTE != 0 THEN
      RESPUESTA := 'ERROR. NO SE PUEDE DESCARTAR A UN CANDIDATO QUE HA SIDO PREVIAMENTE SELECCIONADO' ;
    END IF;      
  ELSIF UPPER(SELECCIONADO) ='Y' AND DESCARTADO IS NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM ENTREVISTA_EXTERNA WHERE EE_COD_ENTREVISTA=UPPER(COD_ENT_EXT) AND EE_DESCARTADO = 'Y';
    IF CF_EXISTE != 0 THEN
      RESPUESTA := 'ERROR. NO SE PUEDE SELECCIONAR A UN CANDIDATO QUE HA SIDO PREVIAMENTE DESCARTADO' ;
    END IF; 
  END IF;
  
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  
	SAVEPOINT actualiza_ent_ext;
	UPDATE ENTREVISTA_EXTERNA
  SET   EE_FECHA            = NVL(FECHA,EE_FECHA),
        EE_PROC_SEL_CF      = NVL(UPPER(PROC_SEL),EE_PROC_SEL_CF),
        EE_COMENTARIOS      = NVL(COMENTARIOS, EE_COMENTARIOS),
        EE_SELECCIONADO     = NVL(UPPER(SELECCIONADO), EE_SELECCIONADO),
        EE_DESCARTADO       = NVL(UPPER(DESCARTADO), EE_DESCARTADO)
  WHERE EE_COD_ENTREVISTA   = UPPER(COD_ENT_EXT);
     
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA ENTREVISTA EXTERNA';
    RAISE EXCEPCION;
  ELSE
    -- se modifican las vacantes. Si no son vÃ¡lidas se hace rollback
    IF VACANTES IS NOT NULL THEN
      -- primero se borran las vacantes existentes de la entrevista, para despues introducir las nuevas
      DELETE FROM ENTREVISTA_SELECCION_VACANTE WHERE ESV_ENT_EXT_CF = UPPER(COD_ENT_EXT);            
      NUM_VAC := REGEXP_COUNT(VACANTES, '<VACANTE>',1,'i');    
      FOR i IN 1..NUM_VAC LOOP          
        AUX_VAC := SUBSTR(VACANTES, REGEXP_INSTR(VACANTES,'<VACANTE>',1,i,1,'i'), 
              REGEXP_INSTR(VACANTES,'</VACANTE>',1,i,0,'i') - REGEXP_INSTR(VACANTES,'<VACANTE>',1,i,1,'i'));                          
        -- Se comprueba que la vacante existe      
        SELECT COUNT(*) INTO CF_EXISTE FROM VACANTE WHERE VA_COD_VACANTE=UPPER(AUX_VAC);    
          IF CF_EXISTE = 0 THEN          
            RESPUESTA := 'ERROR. NO EXISTE NINGUNA VACANTE CON CODIGO ' || UPPER(AUX_VAC);
            ROLLBACK TO actualiza_ent_ext;
            RAISE EXCEPCION;
          ELSE
            -- se asocia la competencia con el candidato
            INSERT INTO ENTREVISTA_SELECCION_VACANTE (ESV_ENT_EXT_CF,ESV_PROC_SEL_CF,ESV_VACANTE_CF)
                        VALUES(UPPER(COD_ENT_EXT),UPPER(PROC_SEL),UPPER(AUX_VAC));
            -- Se comprueba que se ha introducido la nueva fila  
            IF SQL%ROWCOUNT != 1 THEN
              RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA VACANTE ' || UPPER(AUX_VAC) || ' A LA ENTREVISTA ' || UPPER(COD_ENT_EXT);
              ROLLBACK TO actualiza_ent_ext;
              RAISE EXCEPCION;            
            END IF; 
          END IF;
      END LOOP;          
    END IF;
    
    RESPUESTA := 'OK. ENTREVISTA EXTERNA [' || UPPER(COD_ENT_EXT) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_ENT_EXT;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_ENT_INT
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_ENT_INT" (	
  COD_ENT_INT     IN  RC.ENTREVISTA_INTERNA.EI_COD_ENTREVISTA%TYPE,  
  FECHA           IN  RC.ENTREVISTA_INTERNA.EI_FECHA%TYPE,
  SATISFACTORIA   IN  RC.ENTREVISTA_INTERNA.EI_SATISFACTORIA%TYPE,
  COMENTARIOS     IN  RC.ENTREVISTA_INTERNA.EI_COMENTARIOS%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_ENT_INT';
  PAR_ENTRADA := 'CODIGO DE ENTREVISTA INTERNA: ' || COD_ENT_INT || ', FECHA:' || FECHA || ', SATISFACTORIA: ' || SATISFACTORIA || ', COMENTARIOS: ' || COMENTARIOS;                
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_ENT_INT IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA ENTREVISTA INTERNA';
  ELSIF SATISFACTORIA IS NOT NULL AND UPPER(SATISFACTORIA) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI LA ENTREVISTA HA SIDO SATISFACTORIA CON Y/N';
  ELSE
  -- Se controla que la entrevista interna exista
    SELECT COUNT(*) INTO CF_EXISTE FROM ENTREVISTA_INTERNA WHERE EI_COD_ENTREVISTA=UPPER(COD_ENT_INT);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA ENTREVISTA INTERNA CON CODIGO ' || UPPER(COD_ENT_INT);
    END IF;      
  END IF;
  
  --Si se descarta al candidato, hay que introducir comentarios o actualizar los existentes
  IF UPPER(SATISFACTORIA) = 'N' AND COMENTARIOS IS NULL THEN
    RESPUESTA := 'ERROR. ES NECESARIO INTRODUCIR COMENTARIOS CUANDO EL CANDIDATO ES DESCARTADO';
  END IF;
     
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  
	UPDATE ENTREVISTA_INTERNA
  SET   EI_FECHA            = NVL(FECHA,EI_FECHA),
        EI_SATISFACTORIA    = NVL(UPPER(SATISFACTORIA), EI_SATISFACTORIA),        
        EI_COMENTARIOS      = NVL(COMENTARIOS, EI_COMENTARIOS)
  WHERE EI_COD_ENTREVISTA   = UPPER(COD_ENT_INT);
     
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA ENTREVISTA INTERNA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. ENTREVISTA INTERNA [' || UPPER(COD_ENT_INT) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_ENT_INT;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_PRO_CAP
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_PRO_CAP" (	
  COD_PROC_CAP    IN  RC.PROCESO_CAPTACION.PC_COD_PROC_CAP%TYPE,  
  TIPO            IN  RC.PROCESO_CAPTACION.PC_TIPO%TYPE,  
  F_INICIO        IN  RC.PROCESO_CAPTACION.PC_F_INICIO%TYPE,  
  F_FIN           IN  RC.PROCESO_CAPTACION.PC_F_FIN%TYPE,  
  DETALLES        IN  RC.PROCESO_CAPTACION.PC_DETALLES%TYPE,    
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  EXCEPCION       EXCEPTION;
  F_INICIO_PREVIA RC.PROCESO_CAPTACION.PC_F_INICIO%TYPE;  
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_PRO_CAP';
  PAR_ENTRADA :=  'CODIGO DE PROCESO DE CAPTACION: ' || COD_PROC_CAP || ', TIPO:' || TIPO ||', FECHA DE INICIO:' || F_INICIO ||', FECHA DE FIN:' || F_FIN || 
                  ', DETALLES: ' || DETALLES;                
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_PROC_CAP IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DEL PROCESO DE CAPTACION';
  ELSIF TIPO IS NOT NULL AND UPPER(TIPO) NOT IN('PRENSA','RADIO','TV','INTERNET','CORREO','OTRO') THEN
    RESPUESTA := 'ERROR. EL TIPO DE PROCESO DE CAPTACION HA DE SER UNO DE LOS SIGUIENTES: PRENSA,RADIO,TV,INTERNET,CORREO,OTRO';  
  ELSE
  -- Se controla que el proceso de captacion exista
    SELECT COUNT(*) INTO CF_EXISTE FROM PROCESO_CAPTACION WHERE PC_COD_PROC_CAP=UPPER(COD_PROC_CAP);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE CAPTACION CON CODIGO ' || UPPER(COD_PROC_CAP);
    END IF;      
  END IF;
  
  --en caso de indicarse una fecha de fin, se comprueba que no es anterior a la de inicio
  IF F_FIN IS NOT NULL THEN
    IF F_INICIO IS NOT NULL AND F_INICIO > F_FIN THEN
      RESPUESTA := 'ERROR. LA FECHA DE FIN NO PUEDE SER ANTERIOR A LA DE INICIO';
    ELSIF F_INICIO IS NULL THEN
      SELECT PC_F_INICIO INTO F_INICIO_PREVIA FROM PROCESO_CAPTACION WHERE PC_COD_PROC_CAP =UPPER(COD_PROC_CAP);
      IF F_INICIO_PREVIA > F_FIN THEN 
        RESPUESTA := 'ERROR. LA FECHA DE FIN NO PUEDE SER ANTERIOR A LA FECHA DE INICIO EXISTENTE (' || F_INICIO_PREVIA || ')';        
      END IF;      
    END IF;      
  END IF;
     
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  
	UPDATE PROCESO_CAPTACION
  SET   PC_TIPO         = NVL(UPPER(TIPO),PC_TIPO),
        PC_F_INICIO     = NVL(F_INICIO, PC_F_INICIO),        
        PC_F_FIN        = NVL(F_FIN, PC_F_FIN),
        PC_DETALLES     = NVL(DETALLES, PC_DETALLES)
  WHERE PC_COD_PROC_CAP = UPPER(COD_PROC_CAP);
     
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR EL PROCESO DE CAPTACION';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. PROCESO DE CAPTACION [' || UPPER(COD_PROC_CAP) || '] MODIFICADO CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_PRO_CAP;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_PROPUESTA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_PROPUESTA" (	
  COD_PROPUESTA   IN  RC.PROPUESTA.PR_COD_PROPUESTA%TYPE,
  DETALLES        IN  RC.PROPUESTA.PR_DETALLES%TYPE,  
  IMPORTE         IN  RC.PROPUESTA.PR_IMPORTE%TYPE,  
  ACEPTADA        IN  RC.PROPUESTA.PR_ES_ACEPTADA%TYPE,  
  COMERCIAL       IN  RC.PROPUESTA.PR_COMERCIAL_CF%TYPE,  
  F_PROPUESTA     IN  RC.PROPUESTA.PR_F_PROPUESTA%TYPE,  
  F_ACEPTACION    IN  RC.PROPUESTA.PR_F_ACEPTACION%TYPE,  
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_PROPUESTA';
  PAR_ENTRADA :=  'CODIGO DE PROPUESTA: ' || COD_PROPUESTA || ', DETALLES:' || DETALLES ||', IMPORTE:' || IMPORTE ||', ACEPTADA:' || ACEPTADA || 
                  ', COMERCIAL: ' || COMERCIAL || ', FECHA DE PROPUESTA: ' || F_PROPUESTA || ', FECHA DE ACEPTACION: ' || F_ACEPTACION;
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_PROPUESTA IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA PROPUESTA';
  ELSIF COMERCIAL IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM COMERCIAL WHERE CO_COD_COMERCIAL=UPPER(COMERCIAL);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN COMERCIAL CON CODIGO ' || UPPER(COMERCIAL);
    END IF;      
  ELSIF ACEPTADA IS NOT NULL AND UPPER(ACEPTADA) NOT IN ('Y','N') THEN
    RESPUESTA := 'ERROR. ES NECESARIO INDICAR SI LA PROPUESTA HA SIDO ACEPTADA CON Y/N';
  -- si se intenta modificar el estado o la fecha de aceptacion, se comprueba que ambos son null
  ELSIF ACEPTADA IS NOT NULL OR F_ACEPTACION IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM PROPUESTA WHERE PR_COD_PROPUESTA=UPPER(COD_PROPUESTA) AND PR_ES_ACEPTADA IS NULL AND PR_F_ACEPTACION IS NULL;
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO SE PUEDE VOLVER A MODIFICAR EL ESTADO/FECHA DE ACEPTACIÃ“N DE LA PROPUESTA ' || UPPER(COD_PROPUESTA);
    END IF;      
  ELSE
  -- Se controla que la propuesta exista
    SELECT COUNT(*) INTO CF_EXISTE FROM PROPUESTA WHERE PR_COD_PROPUESTA=UPPER(COD_PROPUESTA);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA PROPUESTA CON CODIGO ' || UPPER(COD_PROPUESTA);
    END IF;          
  END IF;
    
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  
	UPDATE PROPUESTA
  SET   PR_DETALLES     = NVL(DETALLES,PR_DETALLES),
        PR_IMPORTE      = NVL(IMPORTE, PR_IMPORTE),        
        PR_ES_ACEPTADA  = NVL(UPPER(ACEPTADA), PR_ES_ACEPTADA),
        PR_COMERCIAL_CF = NVL(UPPER(COMERCIAL), PR_COMERCIAL_CF),
        PR_F_PROPUESTA  = NVL(F_PROPUESTA, PR_F_PROPUESTA),
        PR_F_ACEPTACION = NVL(F_ACEPTACION, PR_F_ACEPTACION)
  WHERE PR_COD_PROPUESTA = UPPER(COD_PROPUESTA);
     
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA PROPUESTA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. PROPUESTA [' || UPPER(COD_PROPUESTA) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_PROPUESTA;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_PRO_SEL
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_PRO_SEL" (	
  COD_PROC_SEL    IN  RC.PROCESO_SELECCION.PS_COD_PROC_SEL%TYPE,    
  F_INICIO        IN  RC.PROCESO_SELECCION.PS_F_INICIO%TYPE,  
  F_FIN           IN  RC.PROCESO_SELECCION.PS_F_FIN%TYPE,  
  COMENTARIOS     IN  RC.PROCESO_SELECCION.PS_COMENTARIOS%TYPE,    
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  EXCEPCION       EXCEPTION;
  F_INICIO_PREVIA RC.PROCESO_SELECCION.PS_F_INICIO%TYPE;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_PRO_SEL';
  PAR_ENTRADA :=  'CODIGO DE PROCESO DE SELECCION: ' || COD_PROC_SEL || ', FECHA DE INICIO:' || F_INICIO ||', FECHA DE FIN:' || F_FIN || ', COMENTARIOS: ' || COMENTARIOS;                
                 
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_PROC_SEL IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DEL PROCESO DE SELECCION';
  ELSE
  -- Se controla que el proceso de seleccion exista
    SELECT COUNT(*) INTO CF_EXISTE FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL=UPPER(COD_PROC_SEL);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN PROCESO DE SELECCION CON CODIGO ' || UPPER(COD_PROC_SEL);      
    END IF;      
  END IF;
  
  --en caso de indicarse una fecha de fin, se comprueba que no es anterior a la de inicio
  IF RESPUESTA IS NULL AND F_FIN IS NOT NULL THEN
    IF F_INICIO IS NOT NULL AND F_INICIO > F_FIN THEN
      RESPUESTA := 'ERROR. LA FECHA DE FIN NO PUEDE SER ANTERIOR A LA DE INICIO';
    ELSE
      SELECT PS_F_INICIO INTO F_INICIO_PREVIA FROM PROCESO_SELECCION WHERE PS_COD_PROC_SEL =UPPER(COD_PROC_SEL);
      IF F_INICIO_PREVIA > F_FIN THEN 
        RESPUESTA := 'ERROR. LA FECHA DE FIN NO PUEDE SER ANTERIOR A LA FECHA DE INICIO EXISTENTE (' || F_INICIO_PREVIA || ')';        
      END IF;      
    END IF;      
  END IF;   
     
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  
	UPDATE PROCESO_SELECCION
  SET   PS_F_INICIO     = NVL(F_INICIO, PS_F_INICIO),        
        PS_F_FIN        = NVL(F_FIN, PS_F_FIN),
        PS_COMENTARIOS  = NVL(COMENTARIOS, PS_COMENTARIOS)
  WHERE PS_COD_PROC_SEL = UPPER(COD_PROC_SEL);
     
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR EL PROCESO DE SELECCION';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. PROCESO DE SELECCION [' || UPPER(COD_PROC_SEL) || '] MODIFICADO CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_PRO_SEL;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_SEDE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_SEDE" (
  COD_SEDE      IN  RC.SEDE.SE_COD_SEDE%TYPE,
  TFNO          IN  RC.SEDE.SE_TELEFONO%TYPE,
  POBLACION     IN  RC.SEDE.SE_POBLACION%TYPE,
	C_POSTAL      IN  RC.SEDE.SE_COD_POSTAL%TYPE,
  DIRECCION     IN  RC.SEDE.SE_DIRECCION%TYPE,
  RESPONSABLE   IN  RC.SEDE.SE_RESPONSABLE%TYPE,  
  COD_SALIDA		OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;  
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_SEDE';
  PAR_ENTRADA := 'CODIGO DE SEDE: ' || COD_SEDE || ', TELEFONO: ' || TFNO || ', POBLACION: ' || POBLACION || ', CODIGO POSTAL: ' || C_POSTAL || ', DIRECCION: ' || DIRECCION || 
                 ', RESPONSABLE: ' || RESPONSABLE;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_SEDE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA SEDE';    
  ELSE  
    -- Se controla que la sede exista
    SELECT COUNT(*) INTO CF_EXISTE FROM SEDE WHERE SE_COD_SEDE=UPPER(COD_SEDE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA SEDE CON CODIGO ' || UPPER(COD_SEDE);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
            
  UPDATE SEDE
  SET   SE_TELEFONO         = NVL(TFNO,SE_TELEFONO),
        SE_POBLACION        = NVL(POBLACION,SE_POBLACION),
        SE_COD_POSTAL       = NVL(C_POSTAL, SE_COD_POSTAL),
        SE_DIRECCION        = NVL(DIRECCION, SE_DIRECCION),
        SE_RESPONSABLE      = NVL(RESPONSABLE, SE_RESPONSABLE)    
  WHERE SE_COD_SEDE         = UPPER(COD_SEDE);
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA SEDE';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. SEDE [' || UPPER(COD_SEDE) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_SEDE;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_VACANTE
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_VACANTE" (
  COD_VACANTE       IN  RC.VACANTE.VA_COD_VACANTE%TYPE,
  N_ESTUDIOS        IN  RC.VACANTE.VA_NIVEL_ESTUDIOS%TYPE,
  ESPECIALIZACION   IN  RC.VACANTE.VA_ESPECIALIZACION%TYPE,
  NUM_PUESTOS       IN  RC.VACANTE.VA_NUM_PUESTOS%TYPE,
  COMPETENCIAS      IN  VARCHAR2,  
  COD_SALIDA		    OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 		    OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;  
  EXCEPCION       EXCEPTION;
  NUM_COMP        NUMBER;
  AUX_COMP        VARCHAR2(10);
  AUX_EXP         VARCHAR2(15);
  CAMPOS          VARCHAR2(200);
  VALORES         VARCHAR2(1000);
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_VACANTE';
  PAR_ENTRADA :=  'CODIGO DE VACANTE: ' || COD_VACANTE || ', NIVEL DE ESTUDIOS: ' || N_ESTUDIOS || ', ESPECIALIZACION: ' || ESPECIALIZACION || 
                  ', NUMERO DE PUESTOS: ' || NUM_PUESTOS || ', COMPETENCIAS: ' || COMPETENCIAS;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_VACANTE IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA VACANTE';    
  ELSIF N_ESTUDIOS IS NOT NULL AND UPPER(N_ESTUDIOS) NOT IN ('ESO','BACHILLERATO','FP','GRADO','MASTER','DOCTORADO') THEN
    RESPUESTA := 'ERROR. EL NIVEL DE ESTUDIOS DEBE SER ALGUNO ENTRE: ESO,BACHILLERATO,FP,GRADO,MASTER,DOCTORADO';
  ELSIF NUM_PUESTOS IS NOT NULL AND NUM_PUESTOS < 1 THEN
    RESPUESTA := 'ERROR. EL NUMERO DE PUESTOS HA DE SER AL MENOS 1';
  ELSE  
    -- Se controla que la vacante exista
    SELECT COUNT(*) INTO CF_EXISTE FROM VACANTE WHERE VA_COD_VACANTE=UPPER(COD_VACANTE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA VACANTE CON CODIGO ' || UPPER(COD_VACANTE);
    END IF;
  END IF;
  
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  SAVEPOINT actualiza_vacante;      
  UPDATE VACANTE
  SET   VA_NIVEL_ESTUDIOS    = NVL(UPPER(N_ESTUDIOS),VA_NIVEL_ESTUDIOS),
        VA_ESPECIALIZACION   = NVL(ESPECIALIZACION,VA_ESPECIALIZACION),
        VA_NUM_PUESTOS       = NVL(NUM_PUESTOS, VA_NUM_PUESTOS)       
  WHERE VA_COD_VACANTE       = UPPER(COD_VACANTE);
    
  -- Se comprueba que se ha introducido la nueva fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA VACANTE';
    RAISE EXCEPCION;
  ELSE   
  -- se modifican las competencias. Si no son vÃ¡lidas se hace rollback
    IF COMPETENCIAS IS NOT NULL THEN
      -- primero se borran las competencias existentes del candidato, para despues introducir las nuevas
      DELETE FROM COMPETENCIA_VACANTE WHERE CV_VACANTE_CF = UPPER(COD_VACANTE);            
      NUM_COMP := REGEXP_COUNT(COMPETENCIAS, '<COMPETENCIA>',1,'i');    
      FOR i IN 1..NUM_COMP LOOP          
        AUX_COMP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'), 
              REGEXP_INSTR(COMPETENCIAS,'</COMPETENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<COMPETENCIA>',1,i,1,'i'));                  
        AUX_EXP := SUBSTR(COMPETENCIAS, REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'), 
             REGEXP_INSTR(COMPETENCIAS,'</EXPERIENCIA>',1,i,0,'i') - REGEXP_INSTR(COMPETENCIAS,'<EXPERIENCIA>',1,i,1,'i'));                       
        -- Se comprueba que la competencia existe      
        SELECT COUNT(*) INTO CF_EXISTE FROM COMPETENCIA WHERE CP_COD_COMPETENCIA=UPPER(AUX_COMP);    
          IF CF_EXISTE = 0 THEN          
            RESPUESTA := 'ERROR. NO EXISTE NINGUNA COMPETENCIA CON CODIGO ' || UPPER(AUX_COMP);
            ROLLBACK TO actualiza_vacante;
            RAISE EXCEPCION;          
          ELSE             
            -- se asocia la competencia con la vacante
            IF UPPER(AUX_EXP) = 'ALTA' OR UPPER(AUX_EXP) = 'MEDIA' OR UPPER(AUX_EXP) = 'BAJA' THEN
              INSERT INTO COMPETENCIA_VACANTE (CV_COMPETENCIA_CF,CV_VACANTE_CF,CV_EXPERIENCIA)
                VALUES(UPPER(AUX_COMP),UPPER(COD_VACANTE),UPPER(AUX_EXP));
            ELSE 
              RESPUESTA := 'ERROR. LA EXPERIENCIA NO PUEDE SER ' || UPPER(AUX_EXP);
              ROLLBACK TO actualiza_vacante;
              RAISE EXCEPCION; 
            END IF;
            -- Se comprueba que se ha introducido la nueva fila  
            IF SQL%ROWCOUNT != 1 THEN
              RESPUESTA := 'ERROR. NO SE HA PODIDO AÃ‘ADIR LA COMPETENCIA ' || UPPER(AUX_COMP) || ' A LA VACANTE ' || UPPER(COD_VACANTE);
              ROLLBACK TO actualiza_vacante;
              RAISE EXCEPCION;            
            END IF; 
          END IF;
      END LOOP;    
    END IF;
    RESPUESTA := 'OK. VACANTE [' || UPPER(COD_VACANTE) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
  END IF;  
	PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_VACANTE;

/
--------------------------------------------------------
--  DDL for Procedure PA_MODIF_VISITA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "RC"."PA_MODIF_VISITA" (	
  COD_VISITA      IN  RC.VISITA.VI_COD_VISITA%TYPE,  
  FECHA           IN  RC.VISITA.VI_FECHA%TYPE,
  COMENTARIOS     IN  RC.VISITA.VI_COMENTARIOS%TYPE,
  COMERCIAL       IN  RC.VISITA.VI_COMERCIAL_CF%TYPE,  
  CLIENTE         IN  RC.VISITA.VI_CLIENTE_CF%TYPE,  
  PROPUESTA       IN  RC.VISITA.VI_PROPUESTA_CF%TYPE,    
  COD_SALIDA		  OUT RC.LOG.LOG_COD_SALIDA%TYPE,
	RESPUESTA 	  	OUT RC.LOG.LOG_RSP%TYPE)
IS
  -- Declaracion de variables
  PROCEDIMIENTO   RC.LOG.LOG_PROCEDIMIENTO%TYPE;
  PAR_ENTRADA     RC.LOG.LOG_PAR_ENTRADA%TYPE;
  CF_EXISTE       NUMBER;
  EXCEPCION       EXCEPTION;
  
BEGIN    
  PROCEDIMIENTO := 'PA_MODIF_VISITA';
  PAR_ENTRADA :=  'CODIGO DE VISITA: ' || COD_VISITA || ', FECHA:' || FECHA || ', COMENTARIOS:' || COMENTARIOS || 
                  ', COMERCIAL: ' || COMERCIAL || ', CLIENTE: ' || CLIENTE || ', PROPUESTA: ' || PROPUESTA;
  COD_SALIDA := 1;
  RESPUESTA := NULL;
  
  -- Se controla que todos los valores obligatorios se hayan introducido
  IF COD_VISITA IS NULL THEN
    RESPUESTA := 'ERROR. ES OBLIGATORIO INDICAR EL CODIGO DE LA VISITA';  
  ELSE
  -- Se controla que la entrevista interna exista
    SELECT COUNT(*) INTO CF_EXISTE FROM VISITA WHERE VI_COD_VISITA=UPPER(COD_VISITA);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA VISITA CON CODIGO ' || UPPER(COD_VISITA);
    END IF;      
  END IF;
     
  -- se controla que los parametros dados existan  
  IF COMERCIAL IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM COMERCIAL WHERE CO_COD_COMERCIAL=UPPER(COMERCIAL);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN COMERCIAL CON CODIGO ' || UPPER(COMERCIAL);
    END IF;
  END IF;
  
  IF CLIENTE IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM CLIENTE WHERE CL_COD_CLIENTE=UPPER(CLIENTE);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUN CLIENTE CON CODIGO ' || UPPER(CLIENTE);
    END IF;
  END IF;
  IF PROPUESTA IS NOT NULL THEN
    SELECT COUNT(*) INTO CF_EXISTE FROM PROPUESTA WHERE PR_COD_PROPUESTA=UPPER(PROPUESTA);
    IF CF_EXISTE = 0 THEN
      RESPUESTA := 'ERROR. NO EXISTE NINGUNA PROPUESTA CON CODIGO ' || UPPER(PROPUESTA);
    END IF;
  END IF;
     
  -- Se lanza una excepcion si se ha producido algun error
  IF RESPUESTA IS NOT NULL THEN    
    RAISE EXCEPCION;
  END IF;
  
	UPDATE VISITA
  SET   VI_FECHA        = NVL(FECHA,VI_FECHA),
        VI_COMENTARIOS  = NVL(COMENTARIOS,VI_COMENTARIOS),
        VI_COMERCIAL_CF = NVL(UPPER(COMERCIAL), VI_COMERCIAL_CF),        
        VI_CLIENTE_CF   = NVL(UPPER(CLIENTE), VI_CLIENTE_CF),
        VI_PROPUESTA_CF = NVL(UPPER(PROPUESTA), VI_PROPUESTA_CF)        
  WHERE VI_COD_VISITA   = UPPER(COD_VISITA);
     
  -- Se comprueba que se ha modificado la fila  
  IF SQL%ROWCOUNT != 1 THEN
    RESPUESTA := 'ERROR. NO SE HA PODIDO MODIFICAR LA VISITA';
    RAISE EXCEPCION;
  ELSE    
    RESPUESTA := 'OK. VISITA [' || UPPER(COD_VISITA) || '] MODIFICADA CORRECTAMENTE';
    COD_SALIDA := 0;
    PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
  END IF;  	
  
  -- Gestion de excepciones
  EXCEPTION
    WHEN EXCEPCION THEN
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);
    WHEN OTHERS THEN
      RESPUESTA := 'ERROR. ' || SQLERRM;
      PA_INSERTA_LOG(PROCEDIMIENTO,PAR_ENTRADA,COD_SALIDA,RESPUESTA);      
END PA_MODIF_VISITA;

/

--------------------------------------------------------
--  DDL for Trigger DISP_DW_CAND_INACTIVOS
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_CAND_INACTIVOS" 
AFTER UPDATE OF EE_SELECCIONADO  OR INSERT OR DELETE ON ENTREVISTA_EXTERNA 
BEGIN 
  PA_DW_CAN_INACT();
END DISP_DW_CAND_INACTIVOS;
/
ALTER TRIGGER "RC"."DISP_DW_CAND_INACTIVOS" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_CLIENTE_TOP_CONTRATOS
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_CLIENTE_TOP_CONTRATOS" 
AFTER UPDATE OF EE_SELECCIONADO OR INSERT OR DELETE ON ENTREVISTA_EXTERNA 
BEGIN 
  PA_DW_CLIENTE_TOP_CONTRATOS();
END DISP_DW_CLIENTE_TOP_CONTRATOS;
/
ALTER TRIGGER "RC"."DISP_DW_CLIENTE_TOP_CONTRATOS" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_COMERCIAL_TOP_VISITAS
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_COMERCIAL_TOP_VISITAS" 
AFTER UPDATE OR INSERT OR DELETE ON VISITA
BEGIN 
  PA_DW_COMERCIAL_TOP_VISITAS();
END DISP_DW_COMERCIAL_TOP_VISITAS;
/
ALTER TRIGGER "RC"."DISP_DW_COMERCIAL_TOP_VISITAS" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_ENT_INT
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_ENT_INT" 
AFTER UPDATE OR INSERT OR DELETE ON ENTREVISTA_INTERNA 
BEGIN 
  PA_DW_ENT_INT_ANYO();
END DISP_DW_ENT_INT;
/
ALTER TRIGGER "RC"."DISP_DW_ENT_INT" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_IMP_TOTAL_PROP
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_IMP_TOTAL_PROP" 
AFTER UPDATE OF PR_IMPORTE,PR_ES_ACEPTADA OR INSERT OR DELETE ON PROPUESTA 
BEGIN 
  PA_DW_IMP_PROP_ACEPTADAS();
END DISP_DW_ENT_INT;
/
ALTER TRIGGER "RC"."DISP_DW_IMP_TOTAL_PROP" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_LIDER_COMERCIAL
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_LIDER_COMERCIAL" 
AFTER UPDATE OR INSERT OR DELETE ON PROPUESTA 
BEGIN 
  PA_DW_LIDER_COMERCIAL();
END DISP_DW_LIDER_COMERCIAL;
/
ALTER TRIGGER "RC"."DISP_DW_LIDER_COMERCIAL" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_PROC_CAPT_HIST
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_PROC_CAPT_HIST" 
AFTER UPDATE OF EE_SELECCIONADO OR INSERT OR DELETE ON ENTREVISTA_EXTERNA 
BEGIN 
  PA_DW_CAPTACION_HIST_EXITO();
END DISP_DW_PROC_CAPT_HIST;
/
ALTER TRIGGER "RC"."DISP_DW_PROC_CAPT_HIST" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_PROC_TOP_ANUAL
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_PROC_TOP_ANUAL" 
AFTER UPDATE OF EE_SELECCIONADO OR INSERT OR DELETE ON ENTREVISTA_EXTERNA 
BEGIN 
  PA_DW_CAPTACION_TOP_ANUAL();
END DISP_DW_PROC_TOP_ANUAL;
/
ALTER TRIGGER "RC"."DISP_DW_PROC_TOP_ANUAL" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_RATIO_PRO_SEL_EXITO
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_RATIO_PRO_SEL_EXITO" 
AFTER UPDATE OF EE_SELECCIONADO OR INSERT OR DELETE ON ENTREVISTA_EXTERNA
BEGIN 
  PA_DW_RATIO_PRO_SEL_EXITO();
END DISP_DW_RATIO_PRO_SEL_EXITO;
/
ALTER TRIGGER "RC"."DISP_DW_RATIO_PRO_SEL_EXITO" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_SEDE_MENOS_ENT
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_SEDE_MENOS_ENT" 
AFTER UPDATE OR INSERT OR DELETE ON ENTREVISTA_INTERNA 
BEGIN 
  PA_DW_SEDE_MENOS_ENTREVISTAS();
END DISP_DW_SEDE_MENOS_ENT;
/
ALTER TRIGGER "RC"."DISP_DW_SEDE_MENOS_ENT" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_TOP_PROP_RECHAZA
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_TOP_PROP_RECHAZA" 
AFTER UPDATE OF PR_ES_ACEPTADA OR INSERT OR DELETE ON PROPUESTA 

DECLARE
  ANYO_INICIO NUMBER;
  ANYO_FINAL NUMBER;  
BEGIN   
  SELECT max(extract(year from PR_F_PROPUESTA)), min(extract(year from PR_F_PROPUESTA))
  INTO ANYO_FINAL, ANYO_INICIO
  FROM PROPUESTA;
  
  FOR anyo IN ANYO_INICIO..ANYO_FINAL
  LOOP
    PA_DW_CLIENTE_PROP_RECHAZA(anyo);
  END LOOP;
END DISP_DW_TOP_PROP_RECHAZA;
/
ALTER TRIGGER "RC"."DISP_DW_TOP_PROP_RECHAZA" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_TOP10_ESTUDIOS
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_TOP10_ESTUDIOS" 
AFTER UPDATE OF VA_NIVEL_ESTUDIOS, VA_ESPECIALIZACION OR INSERT OR DELETE ON VACANTE 
--FOR EACH ROW
DECLARE
  ANYO_INICIO NUMBER;
  ANYO_FINAL NUMBER;  
BEGIN   
  SELECT max(extract(year from ps_f_inicio)), min(extract(year from ps_f_inicio))
  INTO ANYO_FINAL, ANYO_INICIO
  FROM proceso_seleccion;
  
  FOR anyo IN ANYO_INICIO..ANYO_FINAL
  LOOP
    PA_DW_TOP10_ESTUDIOS(anyo);
  END LOOP;
END DISP_DW_TOP10_ESTUDIOS;
/
ALTER TRIGGER "RC"."DISP_DW_TOP10_ESTUDIOS" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_DW_TOP5_COMPETENCIAS
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_DW_TOP5_COMPETENCIAS" 
AFTER UPDATE  OR INSERT OR DELETE ON VACANTE 
DECLARE
  ANYO_INICIO NUMBER;
  ANYO_FINAL NUMBER;  
BEGIN   
  SELECT max(extract(year from ps_f_inicio)), min(extract(year from ps_f_inicio))
  INTO ANYO_FINAL, ANYO_INICIO
  FROM proceso_seleccion;
  
  FOR anyo IN ANYO_INICIO..ANYO_FINAL
  LOOP
    PA_DW_TOP5_COMPETENCIAS(anyo);
  END LOOP;
END DISP_DW_TOP5_COMPETENCIAS;
/
ALTER TRIGGER "RC"."DISP_DW_TOP5_COMPETENCIAS" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_IMPORTE_PROP_COMERCIAL
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_IMPORTE_PROP_COMERCIAL" 
AFTER UPDATE OF PR_ES_ACEPTADA, PR_IMPORTE OR INSERT OR DELETE ON PROPUESTA

BEGIN 
pa_calcula_prop_comercial();  
END DISP_IMPORTE_PROP_COMERCIAL;
/
ALTER TRIGGER "RC"."DISP_IMPORTE_PROP_COMERCIAL" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_CANDIDATO
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_CANDIDATO" 
  BEFORE INSERT ON CANDIDATO
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('CA',TO_CHAR(SEQ_CANDIDATO.NEXTVAL,'FM00000'))
        INTO :NEW.CA_COD_CANDIDATO
        FROM DUAL;      
    END DISP_PK_CANDIDATO;	
/
ALTER TRIGGER "RC"."DISP_PK_CANDIDATO" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_CLIENTE
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_CLIENTE" 
  BEFORE INSERT ON CLIENTE
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('CL',TO_CHAR(SEQ_CLIENTE.NEXTVAL,'FM00000'))
        INTO :NEW.CL_COD_CLIENTE
        FROM DUAL;      
    END DISP_PK_CLIENTE;
/
ALTER TRIGGER "RC"."DISP_PK_CLIENTE" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_COMERCIAL
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_COMERCIAL" 
  BEFORE INSERT ON COMERCIAL
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('CO',TO_CHAR(SEQ_COMERCIAL.NEXTVAL,'FM00000'))
        INTO :NEW.CO_COD_COMERCIAL
        FROM DUAL;      
    END DISP_PK_COMERCIAL;	
/
ALTER TRIGGER "RC"."DISP_PK_COMERCIAL" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_COMPETENCIA
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_COMPETENCIA" 
  BEFORE INSERT ON COMPETENCIA
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('CP',TO_CHAR(SEQ_COMPETENCIA.NEXTVAL,'FM00000'))
        INTO :NEW.CP_COD_COMPETENCIA
        FROM DUAL;      
    END DISP_PK_COMPETENCIA;	
/
ALTER TRIGGER "RC"."DISP_PK_COMPETENCIA" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_ENT_EXTERNA
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_ENT_EXTERNA" 
  BEFORE INSERT ON ENTREVISTA_EXTERNA
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('EE',TO_CHAR(SEQ_ENTREVISTA_EXTERNA.NEXTVAL,'FM00000'))
        INTO :NEW.EE_COD_ENTREVISTA
        FROM DUAL;      
    END DISP_PK_ENT_EXTERNA;	
/
ALTER TRIGGER "RC"."DISP_PK_ENT_EXTERNA" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_ENT_INTERNA
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_ENT_INTERNA" 
  BEFORE INSERT ON ENTREVISTA_INTERNA
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('EI',TO_CHAR(SEQ_ENTREVISTA_INTERNA.NEXTVAL,'FM00000'))
        INTO :NEW.EI_COD_ENTREVISTA
        FROM DUAL;      
    END DISP_PK_ENT_INTERNA;	
/
ALTER TRIGGER "RC"."DISP_PK_ENT_INTERNA" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_LOG
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_LOG" 
  BEFORE INSERT ON LOG
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('LOG',TO_CHAR(SEQ_LOG.NEXTVAL,'FM0000000000'))
        INTO :NEW.LOG_ID
        FROM DUAL;      
    END DISP_PK_LOG;
/
ALTER TRIGGER "RC"."DISP_PK_LOG" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_PROC_CAP
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_PROC_CAP" 
  BEFORE INSERT ON PROCESO_CAPTACION
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('PC',TO_CHAR(SEQ_PRO_CAPTACION.NEXTVAL,'FM00000'))
        INTO :NEW.PC_COD_PROC_CAP
        FROM DUAL;      
    END DISP_PK_PROC_CAP;
/
ALTER TRIGGER "RC"."DISP_PK_PROC_CAP" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_PROC_SEL
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_PROC_SEL" 
  BEFORE INSERT ON PROCESO_SELECCION
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('PS',TO_CHAR(SEQ_PRO_SELECCION.NEXTVAL,'FM00000'))
        INTO :NEW.PS_COD_PROC_SEL
        FROM DUAL;      
    END DISP_PK_PROC_SEL;	
/
ALTER TRIGGER "RC"."DISP_PK_PROC_SEL" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_PROPUESTA
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_PROPUESTA" 
  BEFORE INSERT ON PROPUESTA
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('PR',TO_CHAR(SEQ_PROPUESTA.NEXTVAL,'FM00000'))
        INTO :NEW.PR_COD_PROPUESTA
        FROM DUAL;      
    END DISP_PK_PROPUESTA;	
/
ALTER TRIGGER "RC"."DISP_PK_PROPUESTA" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_SEDE
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_SEDE" 
  BEFORE INSERT ON SEDE
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('SE',TO_CHAR(SEQ_SEDE.NEXTVAL,'FM0000'))
        INTO :NEW.SE_COD_SEDE
        FROM DUAL;      
    END DISP_PK_SEDE;
 
/
ALTER TRIGGER "RC"."DISP_PK_SEDE" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_VACANTE
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_VACANTE" 
  BEFORE INSERT ON VACANTE
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('VA',TO_CHAR(SEQ_VACANTE.NEXTVAL,'FM00000'))
        INTO :NEW.VA_COD_VACANTE
        FROM DUAL;      
    END DISP_PK_VACANTE;	
/
ALTER TRIGGER "RC"."DISP_PK_VACANTE" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_PK_VISITA
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_PK_VISITA" 
  BEFORE INSERT ON VISITA
  FOR EACH ROW      
    BEGIN  
      SELECT CONCAT('VI',TO_CHAR(SEQ_VISITA.NEXTVAL,'FM00000'))
        INTO :NEW.VI_COD_VISITA
        FROM DUAL;      
    END DISP_PK_VISITA;	
/
ALTER TRIGGER "RC"."DISP_PK_VISITA" ENABLE;
--------------------------------------------------------
--  DDL for Trigger DISP_RATIO_DW_RCI
--------------------------------------------------------

  CREATE OR REPLACE TRIGGER "RC"."DISP_RATIO_DW_RCI" 
  BEFORE INSERT ON DW_RATIO_CAN_INACTIVOS
  FOR EACH ROW      
    BEGIN  
      SELECT :NEW.RCI_CAN_INACTIVOS / :NEW.RCI_CAN_TOTALES
        INTO :NEW.RCI_RATIO
        FROM DUAL;      
    END DISP_RATIO_DW_RCI;	
/
ALTER TRIGGER "RC"."DISP_RATIO_DW_RCI" ENABLE;
